#include "atlas_misc.h"
#ifndef PFYDIST
   #define PFYDIST 12
#endif
#ifndef PFXDIST
   #define PFXDIST 0
#endif
#ifndef PFADIST
   #define PFADIST 0
#endif

#if !defined(ATL_3DNow) && !defined(ATL_SSE1) && \
    (PFADIST != 0 || PFXDIST != 0 || PFYDIST != 0)
   #include "atlas_prefetch.h"
#endif

#if defined(ATL_3DNow) || defined(ATL_SSE1)
   #ifndef PFIY
      #define PFIY prefetchnta
   #endif
   #ifndef PFIX
      #define PFIX prefetchnta
   #endif
   #ifndef PFIA
      #ifdef ATL_3DNow
         #define PFIA prefetchw
      #else
         #define PFIA prefetcht0
      #endif
   #endif
#endif
/*
 * X & A are prefetched in M loop PF[A,X]DIST (in bytes) ahead
 */
#if PFADIST == 0                /* flag for no prefetch */
   #define prefA(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefA(mem) __asm__ __volatile__ \
         (Mstr(PFIA) " %0" : : "m" (*(((char *)(mem))+PFADIST)))
   #else
      #if PFLVL == 2
         #define prefA(mem) ATL_pfl2W(((char*)mem)+PFADIST)
      #else
         #define prefA(mem) ATL_pfl1W(((char*)mem)+PFADIST)
      #endif
   #endif
#endif
#if PFXDIST == 0                /* flag for no prefetch */
   #define prefX(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefX(mem) __asm__ __volatile__ \
         (Mstr(PFIX) " %0" : : "m" (*(((char *)(mem))+PFXDIST)))
   #else
      #if PFLVL == 2
         #define prefX(mem) ATL_pfl2R(((char*)mem)+PFXDIST)
      #else
         #define prefX(mem) ATL_pfl1R(((char*)mem)+PFXDIST)
      #endif
   #endif
#endif
/*
 * Y is prefetched in N-loop, and always fetches next NU piece
 */
#if PFYDIST == 0                /* flag for no prefetch */
   #define prefY(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefY(mem) \
         __asm__ __volatile__ (Mstr(PFIY) " %0" : : "m" (*(((char *)(mem)))))
   #else
      #if PFLVL == 2
         #define prefY(mem) ATL_pfl2R(mem)
      #else
         #define prefY(mem) ATL_pfl1R(mem)
      #endif
   #endif
#endif
#ifndef ATL_CINT
   #define ATL_CINT const int
#endif
#ifndef ATL_INT
   #define ATL_INT int
#endif
void ATL_UGER2K(ATL_CINT M, ATL_CINT N, const float *X, const float *Y, 
                const float *W, const float *Z, float *A, ATL_CINT lda)
/*
 * 96x12 unrolled r2_c.
 * Extracted from ATLAS/tune/blas/gemv/atlas-l2g.base
 */
{
   ATL_CINT N12=(N/12)*12, M96=(M/96)*96, lda12=lda*12;
   ATL_INT j;

   for (j=N12; j; j -= 12, A += lda12, Y += 12)
   {
      float *A0=A, *A1=A0+lda, *A2=A1+lda, *A3=A2+lda, *A4=A3+lda, *A5=A4+lda,
            *A6=A5+lda, *A7=A6+lda, *A8=A7+lda, *A9=A8+lda, *A10=A9+lda,
            *A11=A10+lda;
      const register float y0=Y[0], z0=Z[0], y1=Y[1], z1=Z[1], y2=Y[2], z2=Z[2],
                           y3=Y[3], z3=Z[3], y4=Y[4], z4=Z[4], y5=Y[5], z5=Z[5],
                           y6=Y[6], z6=Z[6], y7=Y[7], z7=Z[7], y8=Y[8], z8=Z[8],
                           y9=Y[9], z9=Z[9], y10=Y[10], z10=Z[10], y11=Y[11],
                           z11=Z[11];
      ATL_INT i;
      prefY(Y+12+12-1);
      prefY(Z+12+12-1);
      for (i=0; i < M96; i += 96)
      {
         register float a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11;
         const float x0=X[i+0], w0=W[i+0], x1=X[i+1], w1=W[i+1], x2=X[i+2],
                     w2=W[i+2], x3=X[i+3], w3=W[i+3], x4=X[i+4], w4=W[i+4],
                     x5=X[i+5], w5=W[i+5], x6=X[i+6], w6=W[i+6], x7=X[i+7],
                     w7=W[i+7], x8=X[i+8], w8=W[i+8], x9=X[i+9], w9=W[i+9],
                     x10=X[i+10], w10=W[i+10], x11=X[i+11], w11=W[i+11],
                     x12=X[i+12], w12=W[i+12], x13=X[i+13], w13=W[i+13],
                     x14=X[i+14], w14=W[i+14], x15=X[i+15], w15=W[i+15],
                     x16=X[i+16], w16=W[i+16], x17=X[i+17], w17=W[i+17],
                     x18=X[i+18], w18=W[i+18], x19=X[i+19], w19=W[i+19],
                     x20=X[i+20], w20=W[i+20], x21=X[i+21], w21=W[i+21],
                     x22=X[i+22], w22=W[i+22], x23=X[i+23], w23=W[i+23],
                     x24=X[i+24], w24=W[i+24], x25=X[i+25], w25=W[i+25],
                     x26=X[i+26], w26=W[i+26], x27=X[i+27], w27=W[i+27],
                     x28=X[i+28], w28=W[i+28], x29=X[i+29], w29=W[i+29],
                     x30=X[i+30], w30=W[i+30], x31=X[i+31], w31=W[i+31],
                     x32=X[i+32], w32=W[i+32], x33=X[i+33], w33=W[i+33],
                     x34=X[i+34], w34=W[i+34], x35=X[i+35], w35=W[i+35],
                     x36=X[i+36], w36=W[i+36], x37=X[i+37], w37=W[i+37],
                     x38=X[i+38], w38=W[i+38], x39=X[i+39], w39=W[i+39],
                     x40=X[i+40], w40=W[i+40], x41=X[i+41], w41=W[i+41],
                     x42=X[i+42], w42=W[i+42], x43=X[i+43], w43=W[i+43],
                     x44=X[i+44], w44=W[i+44], x45=X[i+45], w45=W[i+45],
                     x46=X[i+46], w46=W[i+46], x47=X[i+47], w47=W[i+47],
                     x48=X[i+48], w48=W[i+48], x49=X[i+49], w49=W[i+49],
                     x50=X[i+50], w50=W[i+50], x51=X[i+51], w51=W[i+51],
                     x52=X[i+52], w52=W[i+52], x53=X[i+53], w53=W[i+53],
                     x54=X[i+54], w54=W[i+54], x55=X[i+55], w55=W[i+55],
                     x56=X[i+56], w56=W[i+56], x57=X[i+57], w57=W[i+57],
                     x58=X[i+58], w58=W[i+58], x59=X[i+59], w59=W[i+59],
                     x60=X[i+60], w60=W[i+60], x61=X[i+61], w61=W[i+61],
                     x62=X[i+62], w62=W[i+62], x63=X[i+63], w63=W[i+63],
                     x64=X[i+64], w64=W[i+64], x65=X[i+65], w65=W[i+65],
                     x66=X[i+66], w66=W[i+66], x67=X[i+67], w67=W[i+67],
                     x68=X[i+68], w68=W[i+68], x69=X[i+69], w69=W[i+69],
                     x70=X[i+70], w70=W[i+70], x71=X[i+71], w71=W[i+71],
                     x72=X[i+72], w72=W[i+72], x73=X[i+73], w73=W[i+73],
                     x74=X[i+74], w74=W[i+74], x75=X[i+75], w75=W[i+75],
                     x76=X[i+76], w76=W[i+76], x77=X[i+77], w77=W[i+77],
                     x78=X[i+78], w78=W[i+78], x79=X[i+79], w79=W[i+79],
                     x80=X[i+80], w80=W[i+80], x81=X[i+81], w81=W[i+81],
                     x82=X[i+82], w82=W[i+82], x83=X[i+83], w83=W[i+83],
                     x84=X[i+84], w84=W[i+84], x85=X[i+85], w85=W[i+85],
                     x86=X[i+86], w86=W[i+86], x87=X[i+87], w87=W[i+87],
                     x88=X[i+88], w88=W[i+88], x89=X[i+89], w89=W[i+89],
                     x90=X[i+90], w90=W[i+90], x91=X[i+91], w91=W[i+91],
                     x92=X[i+92], w92=W[i+92], x93=X[i+93], w93=W[i+93],
                     x94=X[i+94], w94=W[i+94], x95=X[i+95], w95=W[i+95];

         prefX(X);
         a0 = A0[i+0];
         a0 += x0 * y0;
         a1 = A1[i+0];
         a1 += x0 * y1;
         a2 = A2[i+0];
         a2 += x0 * y2;
         a3 = A3[i+0];
         a3 += x0 * y3;
         a4 = A4[i+0];
         a4 += x0 * y4;
         a5 = A5[i+0];
         a5 += x0 * y5;
         a6 = A6[i+0];
         a6 += x0 * y6;
         a7 = A7[i+0];
         a7 += x0 * y7;
         a8 = A8[i+0];
         a8 += x0 * y8;
         a9 = A9[i+0];
         a9 += x0 * y9;
         a10 = A10[i+0];
         a10 += x0 * y10;
         a11 = A11[i+0];
         a11 += x0 * y11;
         prefX(W);
         a0 += w0 * z0;
         prefA(A0);
         A0[i+0] = a0;
         a1 += w0 * z1;
         prefA(A1);
         A1[i+0] = a1;
         a2 += w0 * z2;
         prefA(A2);
         A2[i+0] = a2;
         a3 += w0 * z3;
         prefA(A3);
         A3[i+0] = a3;
         a4 += w0 * z4;
         prefA(A4);
         A4[i+0] = a4;
         a5 += w0 * z5;
         prefA(A5);
         A5[i+0] = a5;
         a6 += w0 * z6;
         prefA(A6);
         A6[i+0] = a6;
         a7 += w0 * z7;
         prefA(A7);
         A7[i+0] = a7;
         a8 += w0 * z8;
         prefA(A8);
         A8[i+0] = a8;
         a9 += w0 * z9;
         prefA(A9);
         A9[i+0] = a9;
         a10 += w0 * z10;
         prefA(A10);
         A10[i+0] = a10;
         a11 += w0 * z11;
         prefA(A11);
         A11[i+0] = a11;
         a0 = A0[i+1];
         a0 += x1 * y0;
         a1 = A1[i+1];
         a1 += x1 * y1;
         a2 = A2[i+1];
         a2 += x1 * y2;
         a3 = A3[i+1];
         a3 += x1 * y3;
         a4 = A4[i+1];
         a4 += x1 * y4;
         a5 = A5[i+1];
         a5 += x1 * y5;
         a6 = A6[i+1];
         a6 += x1 * y6;
         a7 = A7[i+1];
         a7 += x1 * y7;
         a8 = A8[i+1];
         a8 += x1 * y8;
         a9 = A9[i+1];
         a9 += x1 * y9;
         a10 = A10[i+1];
         a10 += x1 * y10;
         a11 = A11[i+1];
         a11 += x1 * y11;
         a0 += w1 * z0;
         A0[i+1] = a0;
         a1 += w1 * z1;
         A1[i+1] = a1;
         a2 += w1 * z2;
         A2[i+1] = a2;
         a3 += w1 * z3;
         A3[i+1] = a3;
         a4 += w1 * z4;
         A4[i+1] = a4;
         a5 += w1 * z5;
         A5[i+1] = a5;
         a6 += w1 * z6;
         A6[i+1] = a6;
         a7 += w1 * z7;
         A7[i+1] = a7;
         a8 += w1 * z8;
         A8[i+1] = a8;
         a9 += w1 * z9;
         A9[i+1] = a9;
         a10 += w1 * z10;
         A10[i+1] = a10;
         a11 += w1 * z11;
         A11[i+1] = a11;
         a0 = A0[i+2];
         a0 += x2 * y0;
         a1 = A1[i+2];
         a1 += x2 * y1;
         a2 = A2[i+2];
         a2 += x2 * y2;
         a3 = A3[i+2];
         a3 += x2 * y3;
         a4 = A4[i+2];
         a4 += x2 * y4;
         a5 = A5[i+2];
         a5 += x2 * y5;
         a6 = A6[i+2];
         a6 += x2 * y6;
         a7 = A7[i+2];
         a7 += x2 * y7;
         a8 = A8[i+2];
         a8 += x2 * y8;
         a9 = A9[i+2];
         a9 += x2 * y9;
         a10 = A10[i+2];
         a10 += x2 * y10;
         a11 = A11[i+2];
         a11 += x2 * y11;
         a0 += w2 * z0;
         A0[i+2] = a0;
         a1 += w2 * z1;
         A1[i+2] = a1;
         a2 += w2 * z2;
         A2[i+2] = a2;
         a3 += w2 * z3;
         A3[i+2] = a3;
         a4 += w2 * z4;
         A4[i+2] = a4;
         a5 += w2 * z5;
         A5[i+2] = a5;
         a6 += w2 * z6;
         A6[i+2] = a6;
         a7 += w2 * z7;
         A7[i+2] = a7;
         a8 += w2 * z8;
         A8[i+2] = a8;
         a9 += w2 * z9;
         A9[i+2] = a9;
         a10 += w2 * z10;
         A10[i+2] = a10;
         a11 += w2 * z11;
         A11[i+2] = a11;
         a0 = A0[i+3];
         a0 += x3 * y0;
         a1 = A1[i+3];
         a1 += x3 * y1;
         a2 = A2[i+3];
         a2 += x3 * y2;
         a3 = A3[i+3];
         a3 += x3 * y3;
         a4 = A4[i+3];
         a4 += x3 * y4;
         a5 = A5[i+3];
         a5 += x3 * y5;
         a6 = A6[i+3];
         a6 += x3 * y6;
         a7 = A7[i+3];
         a7 += x3 * y7;
         a8 = A8[i+3];
         a8 += x3 * y8;
         a9 = A9[i+3];
         a9 += x3 * y9;
         a10 = A10[i+3];
         a10 += x3 * y10;
         a11 = A11[i+3];
         a11 += x3 * y11;
         a0 += w3 * z0;
         A0[i+3] = a0;
         a1 += w3 * z1;
         A1[i+3] = a1;
         a2 += w3 * z2;
         A2[i+3] = a2;
         a3 += w3 * z3;
         A3[i+3] = a3;
         a4 += w3 * z4;
         A4[i+3] = a4;
         a5 += w3 * z5;
         A5[i+3] = a5;
         a6 += w3 * z6;
         A6[i+3] = a6;
         a7 += w3 * z7;
         A7[i+3] = a7;
         a8 += w3 * z8;
         A8[i+3] = a8;
         a9 += w3 * z9;
         A9[i+3] = a9;
         a10 += w3 * z10;
         A10[i+3] = a10;
         a11 += w3 * z11;
         A11[i+3] = a11;
         a0 = A0[i+4];
         a0 += x4 * y0;
         a1 = A1[i+4];
         a1 += x4 * y1;
         a2 = A2[i+4];
         a2 += x4 * y2;
         a3 = A3[i+4];
         a3 += x4 * y3;
         a4 = A4[i+4];
         a4 += x4 * y4;
         a5 = A5[i+4];
         a5 += x4 * y5;
         a6 = A6[i+4];
         a6 += x4 * y6;
         a7 = A7[i+4];
         a7 += x4 * y7;
         a8 = A8[i+4];
         a8 += x4 * y8;
         a9 = A9[i+4];
         a9 += x4 * y9;
         a10 = A10[i+4];
         a10 += x4 * y10;
         a11 = A11[i+4];
         a11 += x4 * y11;
         a0 += w4 * z0;
         A0[i+4] = a0;
         a1 += w4 * z1;
         A1[i+4] = a1;
         a2 += w4 * z2;
         A2[i+4] = a2;
         a3 += w4 * z3;
         A3[i+4] = a3;
         a4 += w4 * z4;
         A4[i+4] = a4;
         a5 += w4 * z5;
         A5[i+4] = a5;
         a6 += w4 * z6;
         A6[i+4] = a6;
         a7 += w4 * z7;
         A7[i+4] = a7;
         a8 += w4 * z8;
         A8[i+4] = a8;
         a9 += w4 * z9;
         A9[i+4] = a9;
         a10 += w4 * z10;
         A10[i+4] = a10;
         a11 += w4 * z11;
         A11[i+4] = a11;
         a0 = A0[i+5];
         a0 += x5 * y0;
         a1 = A1[i+5];
         a1 += x5 * y1;
         a2 = A2[i+5];
         a2 += x5 * y2;
         a3 = A3[i+5];
         a3 += x5 * y3;
         a4 = A4[i+5];
         a4 += x5 * y4;
         a5 = A5[i+5];
         a5 += x5 * y5;
         a6 = A6[i+5];
         a6 += x5 * y6;
         a7 = A7[i+5];
         a7 += x5 * y7;
         a8 = A8[i+5];
         a8 += x5 * y8;
         a9 = A9[i+5];
         a9 += x5 * y9;
         a10 = A10[i+5];
         a10 += x5 * y10;
         a11 = A11[i+5];
         a11 += x5 * y11;
         a0 += w5 * z0;
         A0[i+5] = a0;
         a1 += w5 * z1;
         A1[i+5] = a1;
         a2 += w5 * z2;
         A2[i+5] = a2;
         a3 += w5 * z3;
         A3[i+5] = a3;
         a4 += w5 * z4;
         A4[i+5] = a4;
         a5 += w5 * z5;
         A5[i+5] = a5;
         a6 += w5 * z6;
         A6[i+5] = a6;
         a7 += w5 * z7;
         A7[i+5] = a7;
         a8 += w5 * z8;
         A8[i+5] = a8;
         a9 += w5 * z9;
         A9[i+5] = a9;
         a10 += w5 * z10;
         A10[i+5] = a10;
         a11 += w5 * z11;
         A11[i+5] = a11;
         a0 = A0[i+6];
         a0 += x6 * y0;
         a1 = A1[i+6];
         a1 += x6 * y1;
         a2 = A2[i+6];
         a2 += x6 * y2;
         a3 = A3[i+6];
         a3 += x6 * y3;
         a4 = A4[i+6];
         a4 += x6 * y4;
         a5 = A5[i+6];
         a5 += x6 * y5;
         a6 = A6[i+6];
         a6 += x6 * y6;
         a7 = A7[i+6];
         a7 += x6 * y7;
         a8 = A8[i+6];
         a8 += x6 * y8;
         a9 = A9[i+6];
         a9 += x6 * y9;
         a10 = A10[i+6];
         a10 += x6 * y10;
         a11 = A11[i+6];
         a11 += x6 * y11;
         a0 += w6 * z0;
         A0[i+6] = a0;
         a1 += w6 * z1;
         A1[i+6] = a1;
         a2 += w6 * z2;
         A2[i+6] = a2;
         a3 += w6 * z3;
         A3[i+6] = a3;
         a4 += w6 * z4;
         A4[i+6] = a4;
         a5 += w6 * z5;
         A5[i+6] = a5;
         a6 += w6 * z6;
         A6[i+6] = a6;
         a7 += w6 * z7;
         A7[i+6] = a7;
         a8 += w6 * z8;
         A8[i+6] = a8;
         a9 += w6 * z9;
         A9[i+6] = a9;
         a10 += w6 * z10;
         A10[i+6] = a10;
         a11 += w6 * z11;
         A11[i+6] = a11;
         a0 = A0[i+7];
         a0 += x7 * y0;
         a1 = A1[i+7];
         a1 += x7 * y1;
         a2 = A2[i+7];
         a2 += x7 * y2;
         a3 = A3[i+7];
         a3 += x7 * y3;
         a4 = A4[i+7];
         a4 += x7 * y4;
         a5 = A5[i+7];
         a5 += x7 * y5;
         a6 = A6[i+7];
         a6 += x7 * y6;
         a7 = A7[i+7];
         a7 += x7 * y7;
         a8 = A8[i+7];
         a8 += x7 * y8;
         a9 = A9[i+7];
         a9 += x7 * y9;
         a10 = A10[i+7];
         a10 += x7 * y10;
         a11 = A11[i+7];
         a11 += x7 * y11;
         a0 += w7 * z0;
         A0[i+7] = a0;
         a1 += w7 * z1;
         A1[i+7] = a1;
         a2 += w7 * z2;
         A2[i+7] = a2;
         a3 += w7 * z3;
         A3[i+7] = a3;
         a4 += w7 * z4;
         A4[i+7] = a4;
         a5 += w7 * z5;
         A5[i+7] = a5;
         a6 += w7 * z6;
         A6[i+7] = a6;
         a7 += w7 * z7;
         A7[i+7] = a7;
         a8 += w7 * z8;
         A8[i+7] = a8;
         a9 += w7 * z9;
         A9[i+7] = a9;
         a10 += w7 * z10;
         A10[i+7] = a10;
         a11 += w7 * z11;
         A11[i+7] = a11;
         a0 = A0[i+8];
         a0 += x8 * y0;
         a1 = A1[i+8];
         a1 += x8 * y1;
         a2 = A2[i+8];
         a2 += x8 * y2;
         a3 = A3[i+8];
         a3 += x8 * y3;
         a4 = A4[i+8];
         a4 += x8 * y4;
         a5 = A5[i+8];
         a5 += x8 * y5;
         a6 = A6[i+8];
         a6 += x8 * y6;
         a7 = A7[i+8];
         a7 += x8 * y7;
         a8 = A8[i+8];
         a8 += x8 * y8;
         a9 = A9[i+8];
         a9 += x8 * y9;
         a10 = A10[i+8];
         a10 += x8 * y10;
         a11 = A11[i+8];
         a11 += x8 * y11;
         a0 += w8 * z0;
         A0[i+8] = a0;
         a1 += w8 * z1;
         A1[i+8] = a1;
         a2 += w8 * z2;
         A2[i+8] = a2;
         a3 += w8 * z3;
         A3[i+8] = a3;
         a4 += w8 * z4;
         A4[i+8] = a4;
         a5 += w8 * z5;
         A5[i+8] = a5;
         a6 += w8 * z6;
         A6[i+8] = a6;
         a7 += w8 * z7;
         A7[i+8] = a7;
         a8 += w8 * z8;
         A8[i+8] = a8;
         a9 += w8 * z9;
         A9[i+8] = a9;
         a10 += w8 * z10;
         A10[i+8] = a10;
         a11 += w8 * z11;
         A11[i+8] = a11;
         a0 = A0[i+9];
         a0 += x9 * y0;
         a1 = A1[i+9];
         a1 += x9 * y1;
         a2 = A2[i+9];
         a2 += x9 * y2;
         a3 = A3[i+9];
         a3 += x9 * y3;
         a4 = A4[i+9];
         a4 += x9 * y4;
         a5 = A5[i+9];
         a5 += x9 * y5;
         a6 = A6[i+9];
         a6 += x9 * y6;
         a7 = A7[i+9];
         a7 += x9 * y7;
         a8 = A8[i+9];
         a8 += x9 * y8;
         a9 = A9[i+9];
         a9 += x9 * y9;
         a10 = A10[i+9];
         a10 += x9 * y10;
         a11 = A11[i+9];
         a11 += x9 * y11;
         a0 += w9 * z0;
         A0[i+9] = a0;
         a1 += w9 * z1;
         A1[i+9] = a1;
         a2 += w9 * z2;
         A2[i+9] = a2;
         a3 += w9 * z3;
         A3[i+9] = a3;
         a4 += w9 * z4;
         A4[i+9] = a4;
         a5 += w9 * z5;
         A5[i+9] = a5;
         a6 += w9 * z6;
         A6[i+9] = a6;
         a7 += w9 * z7;
         A7[i+9] = a7;
         a8 += w9 * z8;
         A8[i+9] = a8;
         a9 += w9 * z9;
         A9[i+9] = a9;
         a10 += w9 * z10;
         A10[i+9] = a10;
         a11 += w9 * z11;
         A11[i+9] = a11;
         a0 = A0[i+10];
         a0 += x10 * y0;
         a1 = A1[i+10];
         a1 += x10 * y1;
         a2 = A2[i+10];
         a2 += x10 * y2;
         a3 = A3[i+10];
         a3 += x10 * y3;
         a4 = A4[i+10];
         a4 += x10 * y4;
         a5 = A5[i+10];
         a5 += x10 * y5;
         a6 = A6[i+10];
         a6 += x10 * y6;
         a7 = A7[i+10];
         a7 += x10 * y7;
         a8 = A8[i+10];
         a8 += x10 * y8;
         a9 = A9[i+10];
         a9 += x10 * y9;
         a10 = A10[i+10];
         a10 += x10 * y10;
         a11 = A11[i+10];
         a11 += x10 * y11;
         a0 += w10 * z0;
         A0[i+10] = a0;
         a1 += w10 * z1;
         A1[i+10] = a1;
         a2 += w10 * z2;
         A2[i+10] = a2;
         a3 += w10 * z3;
         A3[i+10] = a3;
         a4 += w10 * z4;
         A4[i+10] = a4;
         a5 += w10 * z5;
         A5[i+10] = a5;
         a6 += w10 * z6;
         A6[i+10] = a6;
         a7 += w10 * z7;
         A7[i+10] = a7;
         a8 += w10 * z8;
         A8[i+10] = a8;
         a9 += w10 * z9;
         A9[i+10] = a9;
         a10 += w10 * z10;
         A10[i+10] = a10;
         a11 += w10 * z11;
         A11[i+10] = a11;
         a0 = A0[i+11];
         a0 += x11 * y0;
         a1 = A1[i+11];
         a1 += x11 * y1;
         a2 = A2[i+11];
         a2 += x11 * y2;
         a3 = A3[i+11];
         a3 += x11 * y3;
         a4 = A4[i+11];
         a4 += x11 * y4;
         a5 = A5[i+11];
         a5 += x11 * y5;
         a6 = A6[i+11];
         a6 += x11 * y6;
         a7 = A7[i+11];
         a7 += x11 * y7;
         a8 = A8[i+11];
         a8 += x11 * y8;
         a9 = A9[i+11];
         a9 += x11 * y9;
         a10 = A10[i+11];
         a10 += x11 * y10;
         a11 = A11[i+11];
         a11 += x11 * y11;
         a0 += w11 * z0;
         A0[i+11] = a0;
         a1 += w11 * z1;
         A1[i+11] = a1;
         a2 += w11 * z2;
         A2[i+11] = a2;
         a3 += w11 * z3;
         A3[i+11] = a3;
         a4 += w11 * z4;
         A4[i+11] = a4;
         a5 += w11 * z5;
         A5[i+11] = a5;
         a6 += w11 * z6;
         A6[i+11] = a6;
         a7 += w11 * z7;
         A7[i+11] = a7;
         a8 += w11 * z8;
         A8[i+11] = a8;
         a9 += w11 * z9;
         A9[i+11] = a9;
         a10 += w11 * z10;
         A10[i+11] = a10;
         a11 += w11 * z11;
         A11[i+11] = a11;
         a0 = A0[i+12];
         a0 += x12 * y0;
         a1 = A1[i+12];
         a1 += x12 * y1;
         a2 = A2[i+12];
         a2 += x12 * y2;
         a3 = A3[i+12];
         a3 += x12 * y3;
         a4 = A4[i+12];
         a4 += x12 * y4;
         a5 = A5[i+12];
         a5 += x12 * y5;
         a6 = A6[i+12];
         a6 += x12 * y6;
         a7 = A7[i+12];
         a7 += x12 * y7;
         a8 = A8[i+12];
         a8 += x12 * y8;
         a9 = A9[i+12];
         a9 += x12 * y9;
         a10 = A10[i+12];
         a10 += x12 * y10;
         a11 = A11[i+12];
         a11 += x12 * y11;
         a0 += w12 * z0;
         A0[i+12] = a0;
         a1 += w12 * z1;
         A1[i+12] = a1;
         a2 += w12 * z2;
         A2[i+12] = a2;
         a3 += w12 * z3;
         A3[i+12] = a3;
         a4 += w12 * z4;
         A4[i+12] = a4;
         a5 += w12 * z5;
         A5[i+12] = a5;
         a6 += w12 * z6;
         A6[i+12] = a6;
         a7 += w12 * z7;
         A7[i+12] = a7;
         a8 += w12 * z8;
         A8[i+12] = a8;
         a9 += w12 * z9;
         A9[i+12] = a9;
         a10 += w12 * z10;
         A10[i+12] = a10;
         a11 += w12 * z11;
         A11[i+12] = a11;
         a0 = A0[i+13];
         a0 += x13 * y0;
         a1 = A1[i+13];
         a1 += x13 * y1;
         a2 = A2[i+13];
         a2 += x13 * y2;
         a3 = A3[i+13];
         a3 += x13 * y3;
         a4 = A4[i+13];
         a4 += x13 * y4;
         a5 = A5[i+13];
         a5 += x13 * y5;
         a6 = A6[i+13];
         a6 += x13 * y6;
         a7 = A7[i+13];
         a7 += x13 * y7;
         a8 = A8[i+13];
         a8 += x13 * y8;
         a9 = A9[i+13];
         a9 += x13 * y9;
         a10 = A10[i+13];
         a10 += x13 * y10;
         a11 = A11[i+13];
         a11 += x13 * y11;
         a0 += w13 * z0;
         A0[i+13] = a0;
         a1 += w13 * z1;
         A1[i+13] = a1;
         a2 += w13 * z2;
         A2[i+13] = a2;
         a3 += w13 * z3;
         A3[i+13] = a3;
         a4 += w13 * z4;
         A4[i+13] = a4;
         a5 += w13 * z5;
         A5[i+13] = a5;
         a6 += w13 * z6;
         A6[i+13] = a6;
         a7 += w13 * z7;
         A7[i+13] = a7;
         a8 += w13 * z8;
         A8[i+13] = a8;
         a9 += w13 * z9;
         A9[i+13] = a9;
         a10 += w13 * z10;
         A10[i+13] = a10;
         a11 += w13 * z11;
         A11[i+13] = a11;
         a0 = A0[i+14];
         a0 += x14 * y0;
         a1 = A1[i+14];
         a1 += x14 * y1;
         a2 = A2[i+14];
         a2 += x14 * y2;
         a3 = A3[i+14];
         a3 += x14 * y3;
         a4 = A4[i+14];
         a4 += x14 * y4;
         a5 = A5[i+14];
         a5 += x14 * y5;
         a6 = A6[i+14];
         a6 += x14 * y6;
         a7 = A7[i+14];
         a7 += x14 * y7;
         a8 = A8[i+14];
         a8 += x14 * y8;
         a9 = A9[i+14];
         a9 += x14 * y9;
         a10 = A10[i+14];
         a10 += x14 * y10;
         a11 = A11[i+14];
         a11 += x14 * y11;
         a0 += w14 * z0;
         A0[i+14] = a0;
         a1 += w14 * z1;
         A1[i+14] = a1;
         a2 += w14 * z2;
         A2[i+14] = a2;
         a3 += w14 * z3;
         A3[i+14] = a3;
         a4 += w14 * z4;
         A4[i+14] = a4;
         a5 += w14 * z5;
         A5[i+14] = a5;
         a6 += w14 * z6;
         A6[i+14] = a6;
         a7 += w14 * z7;
         A7[i+14] = a7;
         a8 += w14 * z8;
         A8[i+14] = a8;
         a9 += w14 * z9;
         A9[i+14] = a9;
         a10 += w14 * z10;
         A10[i+14] = a10;
         a11 += w14 * z11;
         A11[i+14] = a11;
         a0 = A0[i+15];
         a0 += x15 * y0;
         a1 = A1[i+15];
         a1 += x15 * y1;
         a2 = A2[i+15];
         a2 += x15 * y2;
         a3 = A3[i+15];
         a3 += x15 * y3;
         a4 = A4[i+15];
         a4 += x15 * y4;
         a5 = A5[i+15];
         a5 += x15 * y5;
         a6 = A6[i+15];
         a6 += x15 * y6;
         a7 = A7[i+15];
         a7 += x15 * y7;
         a8 = A8[i+15];
         a8 += x15 * y8;
         a9 = A9[i+15];
         a9 += x15 * y9;
         a10 = A10[i+15];
         a10 += x15 * y10;
         a11 = A11[i+15];
         a11 += x15 * y11;
         a0 += w15 * z0;
         A0[i+15] = a0;
         a1 += w15 * z1;
         A1[i+15] = a1;
         a2 += w15 * z2;
         A2[i+15] = a2;
         a3 += w15 * z3;
         A3[i+15] = a3;
         a4 += w15 * z4;
         A4[i+15] = a4;
         a5 += w15 * z5;
         A5[i+15] = a5;
         a6 += w15 * z6;
         A6[i+15] = a6;
         a7 += w15 * z7;
         A7[i+15] = a7;
         a8 += w15 * z8;
         A8[i+15] = a8;
         a9 += w15 * z9;
         A9[i+15] = a9;
         a10 += w15 * z10;
         A10[i+15] = a10;
         a11 += w15 * z11;
         A11[i+15] = a11;
         a0 = A0[i+16];
         a0 += x16 * y0;
         a1 = A1[i+16];
         a1 += x16 * y1;
         a2 = A2[i+16];
         a2 += x16 * y2;
         a3 = A3[i+16];
         a3 += x16 * y3;
         a4 = A4[i+16];
         a4 += x16 * y4;
         a5 = A5[i+16];
         a5 += x16 * y5;
         a6 = A6[i+16];
         a6 += x16 * y6;
         a7 = A7[i+16];
         a7 += x16 * y7;
         a8 = A8[i+16];
         a8 += x16 * y8;
         a9 = A9[i+16];
         a9 += x16 * y9;
         a10 = A10[i+16];
         a10 += x16 * y10;
         a11 = A11[i+16];
         a11 += x16 * y11;
         a0 += w16 * z0;
         prefA(A0);
         A0[i+16] = a0;
         a1 += w16 * z1;
         prefA(A1);
         A1[i+16] = a1;
         a2 += w16 * z2;
         prefA(A2);
         A2[i+16] = a2;
         a3 += w16 * z3;
         prefA(A3);
         A3[i+16] = a3;
         a4 += w16 * z4;
         prefA(A4);
         A4[i+16] = a4;
         a5 += w16 * z5;
         prefA(A5);
         A5[i+16] = a5;
         a6 += w16 * z6;
         prefA(A6);
         A6[i+16] = a6;
         a7 += w16 * z7;
         prefA(A7);
         A7[i+16] = a7;
         a8 += w16 * z8;
         prefA(A8);
         A8[i+16] = a8;
         a9 += w16 * z9;
         prefA(A9);
         A9[i+16] = a9;
         a10 += w16 * z10;
         prefA(A10);
         A10[i+16] = a10;
         a11 += w16 * z11;
         prefA(A11);
         A11[i+16] = a11;
         a0 = A0[i+17];
         a0 += x17 * y0;
         a1 = A1[i+17];
         a1 += x17 * y1;
         a2 = A2[i+17];
         a2 += x17 * y2;
         a3 = A3[i+17];
         a3 += x17 * y3;
         a4 = A4[i+17];
         a4 += x17 * y4;
         a5 = A5[i+17];
         a5 += x17 * y5;
         a6 = A6[i+17];
         a6 += x17 * y6;
         a7 = A7[i+17];
         a7 += x17 * y7;
         a8 = A8[i+17];
         a8 += x17 * y8;
         a9 = A9[i+17];
         a9 += x17 * y9;
         a10 = A10[i+17];
         a10 += x17 * y10;
         a11 = A11[i+17];
         a11 += x17 * y11;
         a0 += w17 * z0;
         A0[i+17] = a0;
         a1 += w17 * z1;
         A1[i+17] = a1;
         a2 += w17 * z2;
         A2[i+17] = a2;
         a3 += w17 * z3;
         A3[i+17] = a3;
         a4 += w17 * z4;
         A4[i+17] = a4;
         a5 += w17 * z5;
         A5[i+17] = a5;
         a6 += w17 * z6;
         A6[i+17] = a6;
         a7 += w17 * z7;
         A7[i+17] = a7;
         a8 += w17 * z8;
         A8[i+17] = a8;
         a9 += w17 * z9;
         A9[i+17] = a9;
         a10 += w17 * z10;
         A10[i+17] = a10;
         a11 += w17 * z11;
         A11[i+17] = a11;
         a0 = A0[i+18];
         a0 += x18 * y0;
         a1 = A1[i+18];
         a1 += x18 * y1;
         a2 = A2[i+18];
         a2 += x18 * y2;
         a3 = A3[i+18];
         a3 += x18 * y3;
         a4 = A4[i+18];
         a4 += x18 * y4;
         a5 = A5[i+18];
         a5 += x18 * y5;
         a6 = A6[i+18];
         a6 += x18 * y6;
         a7 = A7[i+18];
         a7 += x18 * y7;
         a8 = A8[i+18];
         a8 += x18 * y8;
         a9 = A9[i+18];
         a9 += x18 * y9;
         a10 = A10[i+18];
         a10 += x18 * y10;
         a11 = A11[i+18];
         a11 += x18 * y11;
         a0 += w18 * z0;
         A0[i+18] = a0;
         a1 += w18 * z1;
         A1[i+18] = a1;
         a2 += w18 * z2;
         A2[i+18] = a2;
         a3 += w18 * z3;
         A3[i+18] = a3;
         a4 += w18 * z4;
         A4[i+18] = a4;
         a5 += w18 * z5;
         A5[i+18] = a5;
         a6 += w18 * z6;
         A6[i+18] = a6;
         a7 += w18 * z7;
         A7[i+18] = a7;
         a8 += w18 * z8;
         A8[i+18] = a8;
         a9 += w18 * z9;
         A9[i+18] = a9;
         a10 += w18 * z10;
         A10[i+18] = a10;
         a11 += w18 * z11;
         A11[i+18] = a11;
         a0 = A0[i+19];
         a0 += x19 * y0;
         a1 = A1[i+19];
         a1 += x19 * y1;
         a2 = A2[i+19];
         a2 += x19 * y2;
         a3 = A3[i+19];
         a3 += x19 * y3;
         a4 = A4[i+19];
         a4 += x19 * y4;
         a5 = A5[i+19];
         a5 += x19 * y5;
         a6 = A6[i+19];
         a6 += x19 * y6;
         a7 = A7[i+19];
         a7 += x19 * y7;
         a8 = A8[i+19];
         a8 += x19 * y8;
         a9 = A9[i+19];
         a9 += x19 * y9;
         a10 = A10[i+19];
         a10 += x19 * y10;
         a11 = A11[i+19];
         a11 += x19 * y11;
         a0 += w19 * z0;
         A0[i+19] = a0;
         a1 += w19 * z1;
         A1[i+19] = a1;
         a2 += w19 * z2;
         A2[i+19] = a2;
         a3 += w19 * z3;
         A3[i+19] = a3;
         a4 += w19 * z4;
         A4[i+19] = a4;
         a5 += w19 * z5;
         A5[i+19] = a5;
         a6 += w19 * z6;
         A6[i+19] = a6;
         a7 += w19 * z7;
         A7[i+19] = a7;
         a8 += w19 * z8;
         A8[i+19] = a8;
         a9 += w19 * z9;
         A9[i+19] = a9;
         a10 += w19 * z10;
         A10[i+19] = a10;
         a11 += w19 * z11;
         A11[i+19] = a11;
         a0 = A0[i+20];
         a0 += x20 * y0;
         a1 = A1[i+20];
         a1 += x20 * y1;
         a2 = A2[i+20];
         a2 += x20 * y2;
         a3 = A3[i+20];
         a3 += x20 * y3;
         a4 = A4[i+20];
         a4 += x20 * y4;
         a5 = A5[i+20];
         a5 += x20 * y5;
         a6 = A6[i+20];
         a6 += x20 * y6;
         a7 = A7[i+20];
         a7 += x20 * y7;
         a8 = A8[i+20];
         a8 += x20 * y8;
         a9 = A9[i+20];
         a9 += x20 * y9;
         a10 = A10[i+20];
         a10 += x20 * y10;
         a11 = A11[i+20];
         a11 += x20 * y11;
         a0 += w20 * z0;
         A0[i+20] = a0;
         a1 += w20 * z1;
         A1[i+20] = a1;
         a2 += w20 * z2;
         A2[i+20] = a2;
         a3 += w20 * z3;
         A3[i+20] = a3;
         a4 += w20 * z4;
         A4[i+20] = a4;
         a5 += w20 * z5;
         A5[i+20] = a5;
         a6 += w20 * z6;
         A6[i+20] = a6;
         a7 += w20 * z7;
         A7[i+20] = a7;
         a8 += w20 * z8;
         A8[i+20] = a8;
         a9 += w20 * z9;
         A9[i+20] = a9;
         a10 += w20 * z10;
         A10[i+20] = a10;
         a11 += w20 * z11;
         A11[i+20] = a11;
         a0 = A0[i+21];
         a0 += x21 * y0;
         a1 = A1[i+21];
         a1 += x21 * y1;
         a2 = A2[i+21];
         a2 += x21 * y2;
         a3 = A3[i+21];
         a3 += x21 * y3;
         a4 = A4[i+21];
         a4 += x21 * y4;
         a5 = A5[i+21];
         a5 += x21 * y5;
         a6 = A6[i+21];
         a6 += x21 * y6;
         a7 = A7[i+21];
         a7 += x21 * y7;
         a8 = A8[i+21];
         a8 += x21 * y8;
         a9 = A9[i+21];
         a9 += x21 * y9;
         a10 = A10[i+21];
         a10 += x21 * y10;
         a11 = A11[i+21];
         a11 += x21 * y11;
         a0 += w21 * z0;
         A0[i+21] = a0;
         a1 += w21 * z1;
         A1[i+21] = a1;
         a2 += w21 * z2;
         A2[i+21] = a2;
         a3 += w21 * z3;
         A3[i+21] = a3;
         a4 += w21 * z4;
         A4[i+21] = a4;
         a5 += w21 * z5;
         A5[i+21] = a5;
         a6 += w21 * z6;
         A6[i+21] = a6;
         a7 += w21 * z7;
         A7[i+21] = a7;
         a8 += w21 * z8;
         A8[i+21] = a8;
         a9 += w21 * z9;
         A9[i+21] = a9;
         a10 += w21 * z10;
         A10[i+21] = a10;
         a11 += w21 * z11;
         A11[i+21] = a11;
         a0 = A0[i+22];
         a0 += x22 * y0;
         a1 = A1[i+22];
         a1 += x22 * y1;
         a2 = A2[i+22];
         a2 += x22 * y2;
         a3 = A3[i+22];
         a3 += x22 * y3;
         a4 = A4[i+22];
         a4 += x22 * y4;
         a5 = A5[i+22];
         a5 += x22 * y5;
         a6 = A6[i+22];
         a6 += x22 * y6;
         a7 = A7[i+22];
         a7 += x22 * y7;
         a8 = A8[i+22];
         a8 += x22 * y8;
         a9 = A9[i+22];
         a9 += x22 * y9;
         a10 = A10[i+22];
         a10 += x22 * y10;
         a11 = A11[i+22];
         a11 += x22 * y11;
         a0 += w22 * z0;
         A0[i+22] = a0;
         a1 += w22 * z1;
         A1[i+22] = a1;
         a2 += w22 * z2;
         A2[i+22] = a2;
         a3 += w22 * z3;
         A3[i+22] = a3;
         a4 += w22 * z4;
         A4[i+22] = a4;
         a5 += w22 * z5;
         A5[i+22] = a5;
         a6 += w22 * z6;
         A6[i+22] = a6;
         a7 += w22 * z7;
         A7[i+22] = a7;
         a8 += w22 * z8;
         A8[i+22] = a8;
         a9 += w22 * z9;
         A9[i+22] = a9;
         a10 += w22 * z10;
         A10[i+22] = a10;
         a11 += w22 * z11;
         A11[i+22] = a11;
         a0 = A0[i+23];
         a0 += x23 * y0;
         a1 = A1[i+23];
         a1 += x23 * y1;
         a2 = A2[i+23];
         a2 += x23 * y2;
         a3 = A3[i+23];
         a3 += x23 * y3;
         a4 = A4[i+23];
         a4 += x23 * y4;
         a5 = A5[i+23];
         a5 += x23 * y5;
         a6 = A6[i+23];
         a6 += x23 * y6;
         a7 = A7[i+23];
         a7 += x23 * y7;
         a8 = A8[i+23];
         a8 += x23 * y8;
         a9 = A9[i+23];
         a9 += x23 * y9;
         a10 = A10[i+23];
         a10 += x23 * y10;
         a11 = A11[i+23];
         a11 += x23 * y11;
         a0 += w23 * z0;
         A0[i+23] = a0;
         a1 += w23 * z1;
         A1[i+23] = a1;
         a2 += w23 * z2;
         A2[i+23] = a2;
         a3 += w23 * z3;
         A3[i+23] = a3;
         a4 += w23 * z4;
         A4[i+23] = a4;
         a5 += w23 * z5;
         A5[i+23] = a5;
         a6 += w23 * z6;
         A6[i+23] = a6;
         a7 += w23 * z7;
         A7[i+23] = a7;
         a8 += w23 * z8;
         A8[i+23] = a8;
         a9 += w23 * z9;
         A9[i+23] = a9;
         a10 += w23 * z10;
         A10[i+23] = a10;
         a11 += w23 * z11;
         A11[i+23] = a11;
         a0 = A0[i+24];
         a0 += x24 * y0;
         a1 = A1[i+24];
         a1 += x24 * y1;
         a2 = A2[i+24];
         a2 += x24 * y2;
         a3 = A3[i+24];
         a3 += x24 * y3;
         a4 = A4[i+24];
         a4 += x24 * y4;
         a5 = A5[i+24];
         a5 += x24 * y5;
         a6 = A6[i+24];
         a6 += x24 * y6;
         a7 = A7[i+24];
         a7 += x24 * y7;
         a8 = A8[i+24];
         a8 += x24 * y8;
         a9 = A9[i+24];
         a9 += x24 * y9;
         a10 = A10[i+24];
         a10 += x24 * y10;
         a11 = A11[i+24];
         a11 += x24 * y11;
         a0 += w24 * z0;
         A0[i+24] = a0;
         a1 += w24 * z1;
         A1[i+24] = a1;
         a2 += w24 * z2;
         A2[i+24] = a2;
         a3 += w24 * z3;
         A3[i+24] = a3;
         a4 += w24 * z4;
         A4[i+24] = a4;
         a5 += w24 * z5;
         A5[i+24] = a5;
         a6 += w24 * z6;
         A6[i+24] = a6;
         a7 += w24 * z7;
         A7[i+24] = a7;
         a8 += w24 * z8;
         A8[i+24] = a8;
         a9 += w24 * z9;
         A9[i+24] = a9;
         a10 += w24 * z10;
         A10[i+24] = a10;
         a11 += w24 * z11;
         A11[i+24] = a11;
         a0 = A0[i+25];
         a0 += x25 * y0;
         a1 = A1[i+25];
         a1 += x25 * y1;
         a2 = A2[i+25];
         a2 += x25 * y2;
         a3 = A3[i+25];
         a3 += x25 * y3;
         a4 = A4[i+25];
         a4 += x25 * y4;
         a5 = A5[i+25];
         a5 += x25 * y5;
         a6 = A6[i+25];
         a6 += x25 * y6;
         a7 = A7[i+25];
         a7 += x25 * y7;
         a8 = A8[i+25];
         a8 += x25 * y8;
         a9 = A9[i+25];
         a9 += x25 * y9;
         a10 = A10[i+25];
         a10 += x25 * y10;
         a11 = A11[i+25];
         a11 += x25 * y11;
         a0 += w25 * z0;
         A0[i+25] = a0;
         a1 += w25 * z1;
         A1[i+25] = a1;
         a2 += w25 * z2;
         A2[i+25] = a2;
         a3 += w25 * z3;
         A3[i+25] = a3;
         a4 += w25 * z4;
         A4[i+25] = a4;
         a5 += w25 * z5;
         A5[i+25] = a5;
         a6 += w25 * z6;
         A6[i+25] = a6;
         a7 += w25 * z7;
         A7[i+25] = a7;
         a8 += w25 * z8;
         A8[i+25] = a8;
         a9 += w25 * z9;
         A9[i+25] = a9;
         a10 += w25 * z10;
         A10[i+25] = a10;
         a11 += w25 * z11;
         A11[i+25] = a11;
         a0 = A0[i+26];
         a0 += x26 * y0;
         a1 = A1[i+26];
         a1 += x26 * y1;
         a2 = A2[i+26];
         a2 += x26 * y2;
         a3 = A3[i+26];
         a3 += x26 * y3;
         a4 = A4[i+26];
         a4 += x26 * y4;
         a5 = A5[i+26];
         a5 += x26 * y5;
         a6 = A6[i+26];
         a6 += x26 * y6;
         a7 = A7[i+26];
         a7 += x26 * y7;
         a8 = A8[i+26];
         a8 += x26 * y8;
         a9 = A9[i+26];
         a9 += x26 * y9;
         a10 = A10[i+26];
         a10 += x26 * y10;
         a11 = A11[i+26];
         a11 += x26 * y11;
         a0 += w26 * z0;
         A0[i+26] = a0;
         a1 += w26 * z1;
         A1[i+26] = a1;
         a2 += w26 * z2;
         A2[i+26] = a2;
         a3 += w26 * z3;
         A3[i+26] = a3;
         a4 += w26 * z4;
         A4[i+26] = a4;
         a5 += w26 * z5;
         A5[i+26] = a5;
         a6 += w26 * z6;
         A6[i+26] = a6;
         a7 += w26 * z7;
         A7[i+26] = a7;
         a8 += w26 * z8;
         A8[i+26] = a8;
         a9 += w26 * z9;
         A9[i+26] = a9;
         a10 += w26 * z10;
         A10[i+26] = a10;
         a11 += w26 * z11;
         A11[i+26] = a11;
         a0 = A0[i+27];
         a0 += x27 * y0;
         a1 = A1[i+27];
         a1 += x27 * y1;
         a2 = A2[i+27];
         a2 += x27 * y2;
         a3 = A3[i+27];
         a3 += x27 * y3;
         a4 = A4[i+27];
         a4 += x27 * y4;
         a5 = A5[i+27];
         a5 += x27 * y5;
         a6 = A6[i+27];
         a6 += x27 * y6;
         a7 = A7[i+27];
         a7 += x27 * y7;
         a8 = A8[i+27];
         a8 += x27 * y8;
         a9 = A9[i+27];
         a9 += x27 * y9;
         a10 = A10[i+27];
         a10 += x27 * y10;
         a11 = A11[i+27];
         a11 += x27 * y11;
         a0 += w27 * z0;
         A0[i+27] = a0;
         a1 += w27 * z1;
         A1[i+27] = a1;
         a2 += w27 * z2;
         A2[i+27] = a2;
         a3 += w27 * z3;
         A3[i+27] = a3;
         a4 += w27 * z4;
         A4[i+27] = a4;
         a5 += w27 * z5;
         A5[i+27] = a5;
         a6 += w27 * z6;
         A6[i+27] = a6;
         a7 += w27 * z7;
         A7[i+27] = a7;
         a8 += w27 * z8;
         A8[i+27] = a8;
         a9 += w27 * z9;
         A9[i+27] = a9;
         a10 += w27 * z10;
         A10[i+27] = a10;
         a11 += w27 * z11;
         A11[i+27] = a11;
         a0 = A0[i+28];
         a0 += x28 * y0;
         a1 = A1[i+28];
         a1 += x28 * y1;
         a2 = A2[i+28];
         a2 += x28 * y2;
         a3 = A3[i+28];
         a3 += x28 * y3;
         a4 = A4[i+28];
         a4 += x28 * y4;
         a5 = A5[i+28];
         a5 += x28 * y5;
         a6 = A6[i+28];
         a6 += x28 * y6;
         a7 = A7[i+28];
         a7 += x28 * y7;
         a8 = A8[i+28];
         a8 += x28 * y8;
         a9 = A9[i+28];
         a9 += x28 * y9;
         a10 = A10[i+28];
         a10 += x28 * y10;
         a11 = A11[i+28];
         a11 += x28 * y11;
         a0 += w28 * z0;
         A0[i+28] = a0;
         a1 += w28 * z1;
         A1[i+28] = a1;
         a2 += w28 * z2;
         A2[i+28] = a2;
         a3 += w28 * z3;
         A3[i+28] = a3;
         a4 += w28 * z4;
         A4[i+28] = a4;
         a5 += w28 * z5;
         A5[i+28] = a5;
         a6 += w28 * z6;
         A6[i+28] = a6;
         a7 += w28 * z7;
         A7[i+28] = a7;
         a8 += w28 * z8;
         A8[i+28] = a8;
         a9 += w28 * z9;
         A9[i+28] = a9;
         a10 += w28 * z10;
         A10[i+28] = a10;
         a11 += w28 * z11;
         A11[i+28] = a11;
         a0 = A0[i+29];
         a0 += x29 * y0;
         a1 = A1[i+29];
         a1 += x29 * y1;
         a2 = A2[i+29];
         a2 += x29 * y2;
         a3 = A3[i+29];
         a3 += x29 * y3;
         a4 = A4[i+29];
         a4 += x29 * y4;
         a5 = A5[i+29];
         a5 += x29 * y5;
         a6 = A6[i+29];
         a6 += x29 * y6;
         a7 = A7[i+29];
         a7 += x29 * y7;
         a8 = A8[i+29];
         a8 += x29 * y8;
         a9 = A9[i+29];
         a9 += x29 * y9;
         a10 = A10[i+29];
         a10 += x29 * y10;
         a11 = A11[i+29];
         a11 += x29 * y11;
         a0 += w29 * z0;
         A0[i+29] = a0;
         a1 += w29 * z1;
         A1[i+29] = a1;
         a2 += w29 * z2;
         A2[i+29] = a2;
         a3 += w29 * z3;
         A3[i+29] = a3;
         a4 += w29 * z4;
         A4[i+29] = a4;
         a5 += w29 * z5;
         A5[i+29] = a5;
         a6 += w29 * z6;
         A6[i+29] = a6;
         a7 += w29 * z7;
         A7[i+29] = a7;
         a8 += w29 * z8;
         A8[i+29] = a8;
         a9 += w29 * z9;
         A9[i+29] = a9;
         a10 += w29 * z10;
         A10[i+29] = a10;
         a11 += w29 * z11;
         A11[i+29] = a11;
         a0 = A0[i+30];
         a0 += x30 * y0;
         a1 = A1[i+30];
         a1 += x30 * y1;
         a2 = A2[i+30];
         a2 += x30 * y2;
         a3 = A3[i+30];
         a3 += x30 * y3;
         a4 = A4[i+30];
         a4 += x30 * y4;
         a5 = A5[i+30];
         a5 += x30 * y5;
         a6 = A6[i+30];
         a6 += x30 * y6;
         a7 = A7[i+30];
         a7 += x30 * y7;
         a8 = A8[i+30];
         a8 += x30 * y8;
         a9 = A9[i+30];
         a9 += x30 * y9;
         a10 = A10[i+30];
         a10 += x30 * y10;
         a11 = A11[i+30];
         a11 += x30 * y11;
         a0 += w30 * z0;
         A0[i+30] = a0;
         a1 += w30 * z1;
         A1[i+30] = a1;
         a2 += w30 * z2;
         A2[i+30] = a2;
         a3 += w30 * z3;
         A3[i+30] = a3;
         a4 += w30 * z4;
         A4[i+30] = a4;
         a5 += w30 * z5;
         A5[i+30] = a5;
         a6 += w30 * z6;
         A6[i+30] = a6;
         a7 += w30 * z7;
         A7[i+30] = a7;
         a8 += w30 * z8;
         A8[i+30] = a8;
         a9 += w30 * z9;
         A9[i+30] = a9;
         a10 += w30 * z10;
         A10[i+30] = a10;
         a11 += w30 * z11;
         A11[i+30] = a11;
         a0 = A0[i+31];
         a0 += x31 * y0;
         a1 = A1[i+31];
         a1 += x31 * y1;
         a2 = A2[i+31];
         a2 += x31 * y2;
         a3 = A3[i+31];
         a3 += x31 * y3;
         a4 = A4[i+31];
         a4 += x31 * y4;
         a5 = A5[i+31];
         a5 += x31 * y5;
         a6 = A6[i+31];
         a6 += x31 * y6;
         a7 = A7[i+31];
         a7 += x31 * y7;
         a8 = A8[i+31];
         a8 += x31 * y8;
         a9 = A9[i+31];
         a9 += x31 * y9;
         a10 = A10[i+31];
         a10 += x31 * y10;
         a11 = A11[i+31];
         a11 += x31 * y11;
         a0 += w31 * z0;
         A0[i+31] = a0;
         a1 += w31 * z1;
         A1[i+31] = a1;
         a2 += w31 * z2;
         A2[i+31] = a2;
         a3 += w31 * z3;
         A3[i+31] = a3;
         a4 += w31 * z4;
         A4[i+31] = a4;
         a5 += w31 * z5;
         A5[i+31] = a5;
         a6 += w31 * z6;
         A6[i+31] = a6;
         a7 += w31 * z7;
         A7[i+31] = a7;
         a8 += w31 * z8;
         A8[i+31] = a8;
         a9 += w31 * z9;
         A9[i+31] = a9;
         a10 += w31 * z10;
         A10[i+31] = a10;
         a11 += w31 * z11;
         A11[i+31] = a11;
         a0 = A0[i+32];
         a0 += x32 * y0;
         a1 = A1[i+32];
         a1 += x32 * y1;
         a2 = A2[i+32];
         a2 += x32 * y2;
         a3 = A3[i+32];
         a3 += x32 * y3;
         a4 = A4[i+32];
         a4 += x32 * y4;
         a5 = A5[i+32];
         a5 += x32 * y5;
         a6 = A6[i+32];
         a6 += x32 * y6;
         a7 = A7[i+32];
         a7 += x32 * y7;
         a8 = A8[i+32];
         a8 += x32 * y8;
         a9 = A9[i+32];
         a9 += x32 * y9;
         a10 = A10[i+32];
         a10 += x32 * y10;
         a11 = A11[i+32];
         a11 += x32 * y11;
         a0 += w32 * z0;
         prefA(A0);
         A0[i+32] = a0;
         a1 += w32 * z1;
         prefA(A1);
         A1[i+32] = a1;
         a2 += w32 * z2;
         prefA(A2);
         A2[i+32] = a2;
         a3 += w32 * z3;
         prefA(A3);
         A3[i+32] = a3;
         a4 += w32 * z4;
         prefA(A4);
         A4[i+32] = a4;
         a5 += w32 * z5;
         prefA(A5);
         A5[i+32] = a5;
         a6 += w32 * z6;
         prefA(A6);
         A6[i+32] = a6;
         a7 += w32 * z7;
         prefA(A7);
         A7[i+32] = a7;
         a8 += w32 * z8;
         prefA(A8);
         A8[i+32] = a8;
         a9 += w32 * z9;
         prefA(A9);
         A9[i+32] = a9;
         a10 += w32 * z10;
         prefA(A10);
         A10[i+32] = a10;
         a11 += w32 * z11;
         prefA(A11);
         A11[i+32] = a11;
         a0 = A0[i+33];
         a0 += x33 * y0;
         a1 = A1[i+33];
         a1 += x33 * y1;
         a2 = A2[i+33];
         a2 += x33 * y2;
         a3 = A3[i+33];
         a3 += x33 * y3;
         a4 = A4[i+33];
         a4 += x33 * y4;
         a5 = A5[i+33];
         a5 += x33 * y5;
         a6 = A6[i+33];
         a6 += x33 * y6;
         a7 = A7[i+33];
         a7 += x33 * y7;
         a8 = A8[i+33];
         a8 += x33 * y8;
         a9 = A9[i+33];
         a9 += x33 * y9;
         a10 = A10[i+33];
         a10 += x33 * y10;
         a11 = A11[i+33];
         a11 += x33 * y11;
         a0 += w33 * z0;
         A0[i+33] = a0;
         a1 += w33 * z1;
         A1[i+33] = a1;
         a2 += w33 * z2;
         A2[i+33] = a2;
         a3 += w33 * z3;
         A3[i+33] = a3;
         a4 += w33 * z4;
         A4[i+33] = a4;
         a5 += w33 * z5;
         A5[i+33] = a5;
         a6 += w33 * z6;
         A6[i+33] = a6;
         a7 += w33 * z7;
         A7[i+33] = a7;
         a8 += w33 * z8;
         A8[i+33] = a8;
         a9 += w33 * z9;
         A9[i+33] = a9;
         a10 += w33 * z10;
         A10[i+33] = a10;
         a11 += w33 * z11;
         A11[i+33] = a11;
         a0 = A0[i+34];
         a0 += x34 * y0;
         a1 = A1[i+34];
         a1 += x34 * y1;
         a2 = A2[i+34];
         a2 += x34 * y2;
         a3 = A3[i+34];
         a3 += x34 * y3;
         a4 = A4[i+34];
         a4 += x34 * y4;
         a5 = A5[i+34];
         a5 += x34 * y5;
         a6 = A6[i+34];
         a6 += x34 * y6;
         a7 = A7[i+34];
         a7 += x34 * y7;
         a8 = A8[i+34];
         a8 += x34 * y8;
         a9 = A9[i+34];
         a9 += x34 * y9;
         a10 = A10[i+34];
         a10 += x34 * y10;
         a11 = A11[i+34];
         a11 += x34 * y11;
         a0 += w34 * z0;
         A0[i+34] = a0;
         a1 += w34 * z1;
         A1[i+34] = a1;
         a2 += w34 * z2;
         A2[i+34] = a2;
         a3 += w34 * z3;
         A3[i+34] = a3;
         a4 += w34 * z4;
         A4[i+34] = a4;
         a5 += w34 * z5;
         A5[i+34] = a5;
         a6 += w34 * z6;
         A6[i+34] = a6;
         a7 += w34 * z7;
         A7[i+34] = a7;
         a8 += w34 * z8;
         A8[i+34] = a8;
         a9 += w34 * z9;
         A9[i+34] = a9;
         a10 += w34 * z10;
         A10[i+34] = a10;
         a11 += w34 * z11;
         A11[i+34] = a11;
         a0 = A0[i+35];
         a0 += x35 * y0;
         a1 = A1[i+35];
         a1 += x35 * y1;
         a2 = A2[i+35];
         a2 += x35 * y2;
         a3 = A3[i+35];
         a3 += x35 * y3;
         a4 = A4[i+35];
         a4 += x35 * y4;
         a5 = A5[i+35];
         a5 += x35 * y5;
         a6 = A6[i+35];
         a6 += x35 * y6;
         a7 = A7[i+35];
         a7 += x35 * y7;
         a8 = A8[i+35];
         a8 += x35 * y8;
         a9 = A9[i+35];
         a9 += x35 * y9;
         a10 = A10[i+35];
         a10 += x35 * y10;
         a11 = A11[i+35];
         a11 += x35 * y11;
         a0 += w35 * z0;
         A0[i+35] = a0;
         a1 += w35 * z1;
         A1[i+35] = a1;
         a2 += w35 * z2;
         A2[i+35] = a2;
         a3 += w35 * z3;
         A3[i+35] = a3;
         a4 += w35 * z4;
         A4[i+35] = a4;
         a5 += w35 * z5;
         A5[i+35] = a5;
         a6 += w35 * z6;
         A6[i+35] = a6;
         a7 += w35 * z7;
         A7[i+35] = a7;
         a8 += w35 * z8;
         A8[i+35] = a8;
         a9 += w35 * z9;
         A9[i+35] = a9;
         a10 += w35 * z10;
         A10[i+35] = a10;
         a11 += w35 * z11;
         A11[i+35] = a11;
         a0 = A0[i+36];
         a0 += x36 * y0;
         a1 = A1[i+36];
         a1 += x36 * y1;
         a2 = A2[i+36];
         a2 += x36 * y2;
         a3 = A3[i+36];
         a3 += x36 * y3;
         a4 = A4[i+36];
         a4 += x36 * y4;
         a5 = A5[i+36];
         a5 += x36 * y5;
         a6 = A6[i+36];
         a6 += x36 * y6;
         a7 = A7[i+36];
         a7 += x36 * y7;
         a8 = A8[i+36];
         a8 += x36 * y8;
         a9 = A9[i+36];
         a9 += x36 * y9;
         a10 = A10[i+36];
         a10 += x36 * y10;
         a11 = A11[i+36];
         a11 += x36 * y11;
         a0 += w36 * z0;
         A0[i+36] = a0;
         a1 += w36 * z1;
         A1[i+36] = a1;
         a2 += w36 * z2;
         A2[i+36] = a2;
         a3 += w36 * z3;
         A3[i+36] = a3;
         a4 += w36 * z4;
         A4[i+36] = a4;
         a5 += w36 * z5;
         A5[i+36] = a5;
         a6 += w36 * z6;
         A6[i+36] = a6;
         a7 += w36 * z7;
         A7[i+36] = a7;
         a8 += w36 * z8;
         A8[i+36] = a8;
         a9 += w36 * z9;
         A9[i+36] = a9;
         a10 += w36 * z10;
         A10[i+36] = a10;
         a11 += w36 * z11;
         A11[i+36] = a11;
         a0 = A0[i+37];
         a0 += x37 * y0;
         a1 = A1[i+37];
         a1 += x37 * y1;
         a2 = A2[i+37];
         a2 += x37 * y2;
         a3 = A3[i+37];
         a3 += x37 * y3;
         a4 = A4[i+37];
         a4 += x37 * y4;
         a5 = A5[i+37];
         a5 += x37 * y5;
         a6 = A6[i+37];
         a6 += x37 * y6;
         a7 = A7[i+37];
         a7 += x37 * y7;
         a8 = A8[i+37];
         a8 += x37 * y8;
         a9 = A9[i+37];
         a9 += x37 * y9;
         a10 = A10[i+37];
         a10 += x37 * y10;
         a11 = A11[i+37];
         a11 += x37 * y11;
         a0 += w37 * z0;
         A0[i+37] = a0;
         a1 += w37 * z1;
         A1[i+37] = a1;
         a2 += w37 * z2;
         A2[i+37] = a2;
         a3 += w37 * z3;
         A3[i+37] = a3;
         a4 += w37 * z4;
         A4[i+37] = a4;
         a5 += w37 * z5;
         A5[i+37] = a5;
         a6 += w37 * z6;
         A6[i+37] = a6;
         a7 += w37 * z7;
         A7[i+37] = a7;
         a8 += w37 * z8;
         A8[i+37] = a8;
         a9 += w37 * z9;
         A9[i+37] = a9;
         a10 += w37 * z10;
         A10[i+37] = a10;
         a11 += w37 * z11;
         A11[i+37] = a11;
         a0 = A0[i+38];
         a0 += x38 * y0;
         a1 = A1[i+38];
         a1 += x38 * y1;
         a2 = A2[i+38];
         a2 += x38 * y2;
         a3 = A3[i+38];
         a3 += x38 * y3;
         a4 = A4[i+38];
         a4 += x38 * y4;
         a5 = A5[i+38];
         a5 += x38 * y5;
         a6 = A6[i+38];
         a6 += x38 * y6;
         a7 = A7[i+38];
         a7 += x38 * y7;
         a8 = A8[i+38];
         a8 += x38 * y8;
         a9 = A9[i+38];
         a9 += x38 * y9;
         a10 = A10[i+38];
         a10 += x38 * y10;
         a11 = A11[i+38];
         a11 += x38 * y11;
         a0 += w38 * z0;
         A0[i+38] = a0;
         a1 += w38 * z1;
         A1[i+38] = a1;
         a2 += w38 * z2;
         A2[i+38] = a2;
         a3 += w38 * z3;
         A3[i+38] = a3;
         a4 += w38 * z4;
         A4[i+38] = a4;
         a5 += w38 * z5;
         A5[i+38] = a5;
         a6 += w38 * z6;
         A6[i+38] = a6;
         a7 += w38 * z7;
         A7[i+38] = a7;
         a8 += w38 * z8;
         A8[i+38] = a8;
         a9 += w38 * z9;
         A9[i+38] = a9;
         a10 += w38 * z10;
         A10[i+38] = a10;
         a11 += w38 * z11;
         A11[i+38] = a11;
         a0 = A0[i+39];
         a0 += x39 * y0;
         a1 = A1[i+39];
         a1 += x39 * y1;
         a2 = A2[i+39];
         a2 += x39 * y2;
         a3 = A3[i+39];
         a3 += x39 * y3;
         a4 = A4[i+39];
         a4 += x39 * y4;
         a5 = A5[i+39];
         a5 += x39 * y5;
         a6 = A6[i+39];
         a6 += x39 * y6;
         a7 = A7[i+39];
         a7 += x39 * y7;
         a8 = A8[i+39];
         a8 += x39 * y8;
         a9 = A9[i+39];
         a9 += x39 * y9;
         a10 = A10[i+39];
         a10 += x39 * y10;
         a11 = A11[i+39];
         a11 += x39 * y11;
         a0 += w39 * z0;
         A0[i+39] = a0;
         a1 += w39 * z1;
         A1[i+39] = a1;
         a2 += w39 * z2;
         A2[i+39] = a2;
         a3 += w39 * z3;
         A3[i+39] = a3;
         a4 += w39 * z4;
         A4[i+39] = a4;
         a5 += w39 * z5;
         A5[i+39] = a5;
         a6 += w39 * z6;
         A6[i+39] = a6;
         a7 += w39 * z7;
         A7[i+39] = a7;
         a8 += w39 * z8;
         A8[i+39] = a8;
         a9 += w39 * z9;
         A9[i+39] = a9;
         a10 += w39 * z10;
         A10[i+39] = a10;
         a11 += w39 * z11;
         A11[i+39] = a11;
         a0 = A0[i+40];
         a0 += x40 * y0;
         a1 = A1[i+40];
         a1 += x40 * y1;
         a2 = A2[i+40];
         a2 += x40 * y2;
         a3 = A3[i+40];
         a3 += x40 * y3;
         a4 = A4[i+40];
         a4 += x40 * y4;
         a5 = A5[i+40];
         a5 += x40 * y5;
         a6 = A6[i+40];
         a6 += x40 * y6;
         a7 = A7[i+40];
         a7 += x40 * y7;
         a8 = A8[i+40];
         a8 += x40 * y8;
         a9 = A9[i+40];
         a9 += x40 * y9;
         a10 = A10[i+40];
         a10 += x40 * y10;
         a11 = A11[i+40];
         a11 += x40 * y11;
         a0 += w40 * z0;
         A0[i+40] = a0;
         a1 += w40 * z1;
         A1[i+40] = a1;
         a2 += w40 * z2;
         A2[i+40] = a2;
         a3 += w40 * z3;
         A3[i+40] = a3;
         a4 += w40 * z4;
         A4[i+40] = a4;
         a5 += w40 * z5;
         A5[i+40] = a5;
         a6 += w40 * z6;
         A6[i+40] = a6;
         a7 += w40 * z7;
         A7[i+40] = a7;
         a8 += w40 * z8;
         A8[i+40] = a8;
         a9 += w40 * z9;
         A9[i+40] = a9;
         a10 += w40 * z10;
         A10[i+40] = a10;
         a11 += w40 * z11;
         A11[i+40] = a11;
         a0 = A0[i+41];
         a0 += x41 * y0;
         a1 = A1[i+41];
         a1 += x41 * y1;
         a2 = A2[i+41];
         a2 += x41 * y2;
         a3 = A3[i+41];
         a3 += x41 * y3;
         a4 = A4[i+41];
         a4 += x41 * y4;
         a5 = A5[i+41];
         a5 += x41 * y5;
         a6 = A6[i+41];
         a6 += x41 * y6;
         a7 = A7[i+41];
         a7 += x41 * y7;
         a8 = A8[i+41];
         a8 += x41 * y8;
         a9 = A9[i+41];
         a9 += x41 * y9;
         a10 = A10[i+41];
         a10 += x41 * y10;
         a11 = A11[i+41];
         a11 += x41 * y11;
         a0 += w41 * z0;
         A0[i+41] = a0;
         a1 += w41 * z1;
         A1[i+41] = a1;
         a2 += w41 * z2;
         A2[i+41] = a2;
         a3 += w41 * z3;
         A3[i+41] = a3;
         a4 += w41 * z4;
         A4[i+41] = a4;
         a5 += w41 * z5;
         A5[i+41] = a5;
         a6 += w41 * z6;
         A6[i+41] = a6;
         a7 += w41 * z7;
         A7[i+41] = a7;
         a8 += w41 * z8;
         A8[i+41] = a8;
         a9 += w41 * z9;
         A9[i+41] = a9;
         a10 += w41 * z10;
         A10[i+41] = a10;
         a11 += w41 * z11;
         A11[i+41] = a11;
         a0 = A0[i+42];
         a0 += x42 * y0;
         a1 = A1[i+42];
         a1 += x42 * y1;
         a2 = A2[i+42];
         a2 += x42 * y2;
         a3 = A3[i+42];
         a3 += x42 * y3;
         a4 = A4[i+42];
         a4 += x42 * y4;
         a5 = A5[i+42];
         a5 += x42 * y5;
         a6 = A6[i+42];
         a6 += x42 * y6;
         a7 = A7[i+42];
         a7 += x42 * y7;
         a8 = A8[i+42];
         a8 += x42 * y8;
         a9 = A9[i+42];
         a9 += x42 * y9;
         a10 = A10[i+42];
         a10 += x42 * y10;
         a11 = A11[i+42];
         a11 += x42 * y11;
         a0 += w42 * z0;
         A0[i+42] = a0;
         a1 += w42 * z1;
         A1[i+42] = a1;
         a2 += w42 * z2;
         A2[i+42] = a2;
         a3 += w42 * z3;
         A3[i+42] = a3;
         a4 += w42 * z4;
         A4[i+42] = a4;
         a5 += w42 * z5;
         A5[i+42] = a5;
         a6 += w42 * z6;
         A6[i+42] = a6;
         a7 += w42 * z7;
         A7[i+42] = a7;
         a8 += w42 * z8;
         A8[i+42] = a8;
         a9 += w42 * z9;
         A9[i+42] = a9;
         a10 += w42 * z10;
         A10[i+42] = a10;
         a11 += w42 * z11;
         A11[i+42] = a11;
         a0 = A0[i+43];
         a0 += x43 * y0;
         a1 = A1[i+43];
         a1 += x43 * y1;
         a2 = A2[i+43];
         a2 += x43 * y2;
         a3 = A3[i+43];
         a3 += x43 * y3;
         a4 = A4[i+43];
         a4 += x43 * y4;
         a5 = A5[i+43];
         a5 += x43 * y5;
         a6 = A6[i+43];
         a6 += x43 * y6;
         a7 = A7[i+43];
         a7 += x43 * y7;
         a8 = A8[i+43];
         a8 += x43 * y8;
         a9 = A9[i+43];
         a9 += x43 * y9;
         a10 = A10[i+43];
         a10 += x43 * y10;
         a11 = A11[i+43];
         a11 += x43 * y11;
         a0 += w43 * z0;
         A0[i+43] = a0;
         a1 += w43 * z1;
         A1[i+43] = a1;
         a2 += w43 * z2;
         A2[i+43] = a2;
         a3 += w43 * z3;
         A3[i+43] = a3;
         a4 += w43 * z4;
         A4[i+43] = a4;
         a5 += w43 * z5;
         A5[i+43] = a5;
         a6 += w43 * z6;
         A6[i+43] = a6;
         a7 += w43 * z7;
         A7[i+43] = a7;
         a8 += w43 * z8;
         A8[i+43] = a8;
         a9 += w43 * z9;
         A9[i+43] = a9;
         a10 += w43 * z10;
         A10[i+43] = a10;
         a11 += w43 * z11;
         A11[i+43] = a11;
         a0 = A0[i+44];
         a0 += x44 * y0;
         a1 = A1[i+44];
         a1 += x44 * y1;
         a2 = A2[i+44];
         a2 += x44 * y2;
         a3 = A3[i+44];
         a3 += x44 * y3;
         a4 = A4[i+44];
         a4 += x44 * y4;
         a5 = A5[i+44];
         a5 += x44 * y5;
         a6 = A6[i+44];
         a6 += x44 * y6;
         a7 = A7[i+44];
         a7 += x44 * y7;
         a8 = A8[i+44];
         a8 += x44 * y8;
         a9 = A9[i+44];
         a9 += x44 * y9;
         a10 = A10[i+44];
         a10 += x44 * y10;
         a11 = A11[i+44];
         a11 += x44 * y11;
         a0 += w44 * z0;
         A0[i+44] = a0;
         a1 += w44 * z1;
         A1[i+44] = a1;
         a2 += w44 * z2;
         A2[i+44] = a2;
         a3 += w44 * z3;
         A3[i+44] = a3;
         a4 += w44 * z4;
         A4[i+44] = a4;
         a5 += w44 * z5;
         A5[i+44] = a5;
         a6 += w44 * z6;
         A6[i+44] = a6;
         a7 += w44 * z7;
         A7[i+44] = a7;
         a8 += w44 * z8;
         A8[i+44] = a8;
         a9 += w44 * z9;
         A9[i+44] = a9;
         a10 += w44 * z10;
         A10[i+44] = a10;
         a11 += w44 * z11;
         A11[i+44] = a11;
         a0 = A0[i+45];
         a0 += x45 * y0;
         a1 = A1[i+45];
         a1 += x45 * y1;
         a2 = A2[i+45];
         a2 += x45 * y2;
         a3 = A3[i+45];
         a3 += x45 * y3;
         a4 = A4[i+45];
         a4 += x45 * y4;
         a5 = A5[i+45];
         a5 += x45 * y5;
         a6 = A6[i+45];
         a6 += x45 * y6;
         a7 = A7[i+45];
         a7 += x45 * y7;
         a8 = A8[i+45];
         a8 += x45 * y8;
         a9 = A9[i+45];
         a9 += x45 * y9;
         a10 = A10[i+45];
         a10 += x45 * y10;
         a11 = A11[i+45];
         a11 += x45 * y11;
         a0 += w45 * z0;
         A0[i+45] = a0;
         a1 += w45 * z1;
         A1[i+45] = a1;
         a2 += w45 * z2;
         A2[i+45] = a2;
         a3 += w45 * z3;
         A3[i+45] = a3;
         a4 += w45 * z4;
         A4[i+45] = a4;
         a5 += w45 * z5;
         A5[i+45] = a5;
         a6 += w45 * z6;
         A6[i+45] = a6;
         a7 += w45 * z7;
         A7[i+45] = a7;
         a8 += w45 * z8;
         A8[i+45] = a8;
         a9 += w45 * z9;
         A9[i+45] = a9;
         a10 += w45 * z10;
         A10[i+45] = a10;
         a11 += w45 * z11;
         A11[i+45] = a11;
         a0 = A0[i+46];
         a0 += x46 * y0;
         a1 = A1[i+46];
         a1 += x46 * y1;
         a2 = A2[i+46];
         a2 += x46 * y2;
         a3 = A3[i+46];
         a3 += x46 * y3;
         a4 = A4[i+46];
         a4 += x46 * y4;
         a5 = A5[i+46];
         a5 += x46 * y5;
         a6 = A6[i+46];
         a6 += x46 * y6;
         a7 = A7[i+46];
         a7 += x46 * y7;
         a8 = A8[i+46];
         a8 += x46 * y8;
         a9 = A9[i+46];
         a9 += x46 * y9;
         a10 = A10[i+46];
         a10 += x46 * y10;
         a11 = A11[i+46];
         a11 += x46 * y11;
         a0 += w46 * z0;
         A0[i+46] = a0;
         a1 += w46 * z1;
         A1[i+46] = a1;
         a2 += w46 * z2;
         A2[i+46] = a2;
         a3 += w46 * z3;
         A3[i+46] = a3;
         a4 += w46 * z4;
         A4[i+46] = a4;
         a5 += w46 * z5;
         A5[i+46] = a5;
         a6 += w46 * z6;
         A6[i+46] = a6;
         a7 += w46 * z7;
         A7[i+46] = a7;
         a8 += w46 * z8;
         A8[i+46] = a8;
         a9 += w46 * z9;
         A9[i+46] = a9;
         a10 += w46 * z10;
         A10[i+46] = a10;
         a11 += w46 * z11;
         A11[i+46] = a11;
         a0 = A0[i+47];
         a0 += x47 * y0;
         a1 = A1[i+47];
         a1 += x47 * y1;
         a2 = A2[i+47];
         a2 += x47 * y2;
         a3 = A3[i+47];
         a3 += x47 * y3;
         a4 = A4[i+47];
         a4 += x47 * y4;
         a5 = A5[i+47];
         a5 += x47 * y5;
         a6 = A6[i+47];
         a6 += x47 * y6;
         a7 = A7[i+47];
         a7 += x47 * y7;
         a8 = A8[i+47];
         a8 += x47 * y8;
         a9 = A9[i+47];
         a9 += x47 * y9;
         a10 = A10[i+47];
         a10 += x47 * y10;
         a11 = A11[i+47];
         a11 += x47 * y11;
         a0 += w47 * z0;
         A0[i+47] = a0;
         a1 += w47 * z1;
         A1[i+47] = a1;
         a2 += w47 * z2;
         A2[i+47] = a2;
         a3 += w47 * z3;
         A3[i+47] = a3;
         a4 += w47 * z4;
         A4[i+47] = a4;
         a5 += w47 * z5;
         A5[i+47] = a5;
         a6 += w47 * z6;
         A6[i+47] = a6;
         a7 += w47 * z7;
         A7[i+47] = a7;
         a8 += w47 * z8;
         A8[i+47] = a8;
         a9 += w47 * z9;
         A9[i+47] = a9;
         a10 += w47 * z10;
         A10[i+47] = a10;
         a11 += w47 * z11;
         A11[i+47] = a11;
         a0 = A0[i+48];
         a0 += x48 * y0;
         a1 = A1[i+48];
         a1 += x48 * y1;
         a2 = A2[i+48];
         a2 += x48 * y2;
         a3 = A3[i+48];
         a3 += x48 * y3;
         a4 = A4[i+48];
         a4 += x48 * y4;
         a5 = A5[i+48];
         a5 += x48 * y5;
         a6 = A6[i+48];
         a6 += x48 * y6;
         a7 = A7[i+48];
         a7 += x48 * y7;
         a8 = A8[i+48];
         a8 += x48 * y8;
         a9 = A9[i+48];
         a9 += x48 * y9;
         a10 = A10[i+48];
         a10 += x48 * y10;
         a11 = A11[i+48];
         a11 += x48 * y11;
         a0 += w48 * z0;
         prefA(A0);
         A0[i+48] = a0;
         a1 += w48 * z1;
         prefA(A1);
         A1[i+48] = a1;
         a2 += w48 * z2;
         prefA(A2);
         A2[i+48] = a2;
         a3 += w48 * z3;
         prefA(A3);
         A3[i+48] = a3;
         a4 += w48 * z4;
         prefA(A4);
         A4[i+48] = a4;
         a5 += w48 * z5;
         prefA(A5);
         A5[i+48] = a5;
         a6 += w48 * z6;
         prefA(A6);
         A6[i+48] = a6;
         a7 += w48 * z7;
         prefA(A7);
         A7[i+48] = a7;
         a8 += w48 * z8;
         prefA(A8);
         A8[i+48] = a8;
         a9 += w48 * z9;
         prefA(A9);
         A9[i+48] = a9;
         a10 += w48 * z10;
         prefA(A10);
         A10[i+48] = a10;
         a11 += w48 * z11;
         prefA(A11);
         A11[i+48] = a11;
         a0 = A0[i+49];
         a0 += x49 * y0;
         a1 = A1[i+49];
         a1 += x49 * y1;
         a2 = A2[i+49];
         a2 += x49 * y2;
         a3 = A3[i+49];
         a3 += x49 * y3;
         a4 = A4[i+49];
         a4 += x49 * y4;
         a5 = A5[i+49];
         a5 += x49 * y5;
         a6 = A6[i+49];
         a6 += x49 * y6;
         a7 = A7[i+49];
         a7 += x49 * y7;
         a8 = A8[i+49];
         a8 += x49 * y8;
         a9 = A9[i+49];
         a9 += x49 * y9;
         a10 = A10[i+49];
         a10 += x49 * y10;
         a11 = A11[i+49];
         a11 += x49 * y11;
         a0 += w49 * z0;
         A0[i+49] = a0;
         a1 += w49 * z1;
         A1[i+49] = a1;
         a2 += w49 * z2;
         A2[i+49] = a2;
         a3 += w49 * z3;
         A3[i+49] = a3;
         a4 += w49 * z4;
         A4[i+49] = a4;
         a5 += w49 * z5;
         A5[i+49] = a5;
         a6 += w49 * z6;
         A6[i+49] = a6;
         a7 += w49 * z7;
         A7[i+49] = a7;
         a8 += w49 * z8;
         A8[i+49] = a8;
         a9 += w49 * z9;
         A9[i+49] = a9;
         a10 += w49 * z10;
         A10[i+49] = a10;
         a11 += w49 * z11;
         A11[i+49] = a11;
         a0 = A0[i+50];
         a0 += x50 * y0;
         a1 = A1[i+50];
         a1 += x50 * y1;
         a2 = A2[i+50];
         a2 += x50 * y2;
         a3 = A3[i+50];
         a3 += x50 * y3;
         a4 = A4[i+50];
         a4 += x50 * y4;
         a5 = A5[i+50];
         a5 += x50 * y5;
         a6 = A6[i+50];
         a6 += x50 * y6;
         a7 = A7[i+50];
         a7 += x50 * y7;
         a8 = A8[i+50];
         a8 += x50 * y8;
         a9 = A9[i+50];
         a9 += x50 * y9;
         a10 = A10[i+50];
         a10 += x50 * y10;
         a11 = A11[i+50];
         a11 += x50 * y11;
         a0 += w50 * z0;
         A0[i+50] = a0;
         a1 += w50 * z1;
         A1[i+50] = a1;
         a2 += w50 * z2;
         A2[i+50] = a2;
         a3 += w50 * z3;
         A3[i+50] = a3;
         a4 += w50 * z4;
         A4[i+50] = a4;
         a5 += w50 * z5;
         A5[i+50] = a5;
         a6 += w50 * z6;
         A6[i+50] = a6;
         a7 += w50 * z7;
         A7[i+50] = a7;
         a8 += w50 * z8;
         A8[i+50] = a8;
         a9 += w50 * z9;
         A9[i+50] = a9;
         a10 += w50 * z10;
         A10[i+50] = a10;
         a11 += w50 * z11;
         A11[i+50] = a11;
         a0 = A0[i+51];
         a0 += x51 * y0;
         a1 = A1[i+51];
         a1 += x51 * y1;
         a2 = A2[i+51];
         a2 += x51 * y2;
         a3 = A3[i+51];
         a3 += x51 * y3;
         a4 = A4[i+51];
         a4 += x51 * y4;
         a5 = A5[i+51];
         a5 += x51 * y5;
         a6 = A6[i+51];
         a6 += x51 * y6;
         a7 = A7[i+51];
         a7 += x51 * y7;
         a8 = A8[i+51];
         a8 += x51 * y8;
         a9 = A9[i+51];
         a9 += x51 * y9;
         a10 = A10[i+51];
         a10 += x51 * y10;
         a11 = A11[i+51];
         a11 += x51 * y11;
         a0 += w51 * z0;
         A0[i+51] = a0;
         a1 += w51 * z1;
         A1[i+51] = a1;
         a2 += w51 * z2;
         A2[i+51] = a2;
         a3 += w51 * z3;
         A3[i+51] = a3;
         a4 += w51 * z4;
         A4[i+51] = a4;
         a5 += w51 * z5;
         A5[i+51] = a5;
         a6 += w51 * z6;
         A6[i+51] = a6;
         a7 += w51 * z7;
         A7[i+51] = a7;
         a8 += w51 * z8;
         A8[i+51] = a8;
         a9 += w51 * z9;
         A9[i+51] = a9;
         a10 += w51 * z10;
         A10[i+51] = a10;
         a11 += w51 * z11;
         A11[i+51] = a11;
         a0 = A0[i+52];
         a0 += x52 * y0;
         a1 = A1[i+52];
         a1 += x52 * y1;
         a2 = A2[i+52];
         a2 += x52 * y2;
         a3 = A3[i+52];
         a3 += x52 * y3;
         a4 = A4[i+52];
         a4 += x52 * y4;
         a5 = A5[i+52];
         a5 += x52 * y5;
         a6 = A6[i+52];
         a6 += x52 * y6;
         a7 = A7[i+52];
         a7 += x52 * y7;
         a8 = A8[i+52];
         a8 += x52 * y8;
         a9 = A9[i+52];
         a9 += x52 * y9;
         a10 = A10[i+52];
         a10 += x52 * y10;
         a11 = A11[i+52];
         a11 += x52 * y11;
         a0 += w52 * z0;
         A0[i+52] = a0;
         a1 += w52 * z1;
         A1[i+52] = a1;
         a2 += w52 * z2;
         A2[i+52] = a2;
         a3 += w52 * z3;
         A3[i+52] = a3;
         a4 += w52 * z4;
         A4[i+52] = a4;
         a5 += w52 * z5;
         A5[i+52] = a5;
         a6 += w52 * z6;
         A6[i+52] = a6;
         a7 += w52 * z7;
         A7[i+52] = a7;
         a8 += w52 * z8;
         A8[i+52] = a8;
         a9 += w52 * z9;
         A9[i+52] = a9;
         a10 += w52 * z10;
         A10[i+52] = a10;
         a11 += w52 * z11;
         A11[i+52] = a11;
         a0 = A0[i+53];
         a0 += x53 * y0;
         a1 = A1[i+53];
         a1 += x53 * y1;
         a2 = A2[i+53];
         a2 += x53 * y2;
         a3 = A3[i+53];
         a3 += x53 * y3;
         a4 = A4[i+53];
         a4 += x53 * y4;
         a5 = A5[i+53];
         a5 += x53 * y5;
         a6 = A6[i+53];
         a6 += x53 * y6;
         a7 = A7[i+53];
         a7 += x53 * y7;
         a8 = A8[i+53];
         a8 += x53 * y8;
         a9 = A9[i+53];
         a9 += x53 * y9;
         a10 = A10[i+53];
         a10 += x53 * y10;
         a11 = A11[i+53];
         a11 += x53 * y11;
         a0 += w53 * z0;
         A0[i+53] = a0;
         a1 += w53 * z1;
         A1[i+53] = a1;
         a2 += w53 * z2;
         A2[i+53] = a2;
         a3 += w53 * z3;
         A3[i+53] = a3;
         a4 += w53 * z4;
         A4[i+53] = a4;
         a5 += w53 * z5;
         A5[i+53] = a5;
         a6 += w53 * z6;
         A6[i+53] = a6;
         a7 += w53 * z7;
         A7[i+53] = a7;
         a8 += w53 * z8;
         A8[i+53] = a8;
         a9 += w53 * z9;
         A9[i+53] = a9;
         a10 += w53 * z10;
         A10[i+53] = a10;
         a11 += w53 * z11;
         A11[i+53] = a11;
         a0 = A0[i+54];
         a0 += x54 * y0;
         a1 = A1[i+54];
         a1 += x54 * y1;
         a2 = A2[i+54];
         a2 += x54 * y2;
         a3 = A3[i+54];
         a3 += x54 * y3;
         a4 = A4[i+54];
         a4 += x54 * y4;
         a5 = A5[i+54];
         a5 += x54 * y5;
         a6 = A6[i+54];
         a6 += x54 * y6;
         a7 = A7[i+54];
         a7 += x54 * y7;
         a8 = A8[i+54];
         a8 += x54 * y8;
         a9 = A9[i+54];
         a9 += x54 * y9;
         a10 = A10[i+54];
         a10 += x54 * y10;
         a11 = A11[i+54];
         a11 += x54 * y11;
         a0 += w54 * z0;
         A0[i+54] = a0;
         a1 += w54 * z1;
         A1[i+54] = a1;
         a2 += w54 * z2;
         A2[i+54] = a2;
         a3 += w54 * z3;
         A3[i+54] = a3;
         a4 += w54 * z4;
         A4[i+54] = a4;
         a5 += w54 * z5;
         A5[i+54] = a5;
         a6 += w54 * z6;
         A6[i+54] = a6;
         a7 += w54 * z7;
         A7[i+54] = a7;
         a8 += w54 * z8;
         A8[i+54] = a8;
         a9 += w54 * z9;
         A9[i+54] = a9;
         a10 += w54 * z10;
         A10[i+54] = a10;
         a11 += w54 * z11;
         A11[i+54] = a11;
         a0 = A0[i+55];
         a0 += x55 * y0;
         a1 = A1[i+55];
         a1 += x55 * y1;
         a2 = A2[i+55];
         a2 += x55 * y2;
         a3 = A3[i+55];
         a3 += x55 * y3;
         a4 = A4[i+55];
         a4 += x55 * y4;
         a5 = A5[i+55];
         a5 += x55 * y5;
         a6 = A6[i+55];
         a6 += x55 * y6;
         a7 = A7[i+55];
         a7 += x55 * y7;
         a8 = A8[i+55];
         a8 += x55 * y8;
         a9 = A9[i+55];
         a9 += x55 * y9;
         a10 = A10[i+55];
         a10 += x55 * y10;
         a11 = A11[i+55];
         a11 += x55 * y11;
         a0 += w55 * z0;
         A0[i+55] = a0;
         a1 += w55 * z1;
         A1[i+55] = a1;
         a2 += w55 * z2;
         A2[i+55] = a2;
         a3 += w55 * z3;
         A3[i+55] = a3;
         a4 += w55 * z4;
         A4[i+55] = a4;
         a5 += w55 * z5;
         A5[i+55] = a5;
         a6 += w55 * z6;
         A6[i+55] = a6;
         a7 += w55 * z7;
         A7[i+55] = a7;
         a8 += w55 * z8;
         A8[i+55] = a8;
         a9 += w55 * z9;
         A9[i+55] = a9;
         a10 += w55 * z10;
         A10[i+55] = a10;
         a11 += w55 * z11;
         A11[i+55] = a11;
         a0 = A0[i+56];
         a0 += x56 * y0;
         a1 = A1[i+56];
         a1 += x56 * y1;
         a2 = A2[i+56];
         a2 += x56 * y2;
         a3 = A3[i+56];
         a3 += x56 * y3;
         a4 = A4[i+56];
         a4 += x56 * y4;
         a5 = A5[i+56];
         a5 += x56 * y5;
         a6 = A6[i+56];
         a6 += x56 * y6;
         a7 = A7[i+56];
         a7 += x56 * y7;
         a8 = A8[i+56];
         a8 += x56 * y8;
         a9 = A9[i+56];
         a9 += x56 * y9;
         a10 = A10[i+56];
         a10 += x56 * y10;
         a11 = A11[i+56];
         a11 += x56 * y11;
         a0 += w56 * z0;
         A0[i+56] = a0;
         a1 += w56 * z1;
         A1[i+56] = a1;
         a2 += w56 * z2;
         A2[i+56] = a2;
         a3 += w56 * z3;
         A3[i+56] = a3;
         a4 += w56 * z4;
         A4[i+56] = a4;
         a5 += w56 * z5;
         A5[i+56] = a5;
         a6 += w56 * z6;
         A6[i+56] = a6;
         a7 += w56 * z7;
         A7[i+56] = a7;
         a8 += w56 * z8;
         A8[i+56] = a8;
         a9 += w56 * z9;
         A9[i+56] = a9;
         a10 += w56 * z10;
         A10[i+56] = a10;
         a11 += w56 * z11;
         A11[i+56] = a11;
         a0 = A0[i+57];
         a0 += x57 * y0;
         a1 = A1[i+57];
         a1 += x57 * y1;
         a2 = A2[i+57];
         a2 += x57 * y2;
         a3 = A3[i+57];
         a3 += x57 * y3;
         a4 = A4[i+57];
         a4 += x57 * y4;
         a5 = A5[i+57];
         a5 += x57 * y5;
         a6 = A6[i+57];
         a6 += x57 * y6;
         a7 = A7[i+57];
         a7 += x57 * y7;
         a8 = A8[i+57];
         a8 += x57 * y8;
         a9 = A9[i+57];
         a9 += x57 * y9;
         a10 = A10[i+57];
         a10 += x57 * y10;
         a11 = A11[i+57];
         a11 += x57 * y11;
         a0 += w57 * z0;
         A0[i+57] = a0;
         a1 += w57 * z1;
         A1[i+57] = a1;
         a2 += w57 * z2;
         A2[i+57] = a2;
         a3 += w57 * z3;
         A3[i+57] = a3;
         a4 += w57 * z4;
         A4[i+57] = a4;
         a5 += w57 * z5;
         A5[i+57] = a5;
         a6 += w57 * z6;
         A6[i+57] = a6;
         a7 += w57 * z7;
         A7[i+57] = a7;
         a8 += w57 * z8;
         A8[i+57] = a8;
         a9 += w57 * z9;
         A9[i+57] = a9;
         a10 += w57 * z10;
         A10[i+57] = a10;
         a11 += w57 * z11;
         A11[i+57] = a11;
         a0 = A0[i+58];
         a0 += x58 * y0;
         a1 = A1[i+58];
         a1 += x58 * y1;
         a2 = A2[i+58];
         a2 += x58 * y2;
         a3 = A3[i+58];
         a3 += x58 * y3;
         a4 = A4[i+58];
         a4 += x58 * y4;
         a5 = A5[i+58];
         a5 += x58 * y5;
         a6 = A6[i+58];
         a6 += x58 * y6;
         a7 = A7[i+58];
         a7 += x58 * y7;
         a8 = A8[i+58];
         a8 += x58 * y8;
         a9 = A9[i+58];
         a9 += x58 * y9;
         a10 = A10[i+58];
         a10 += x58 * y10;
         a11 = A11[i+58];
         a11 += x58 * y11;
         a0 += w58 * z0;
         A0[i+58] = a0;
         a1 += w58 * z1;
         A1[i+58] = a1;
         a2 += w58 * z2;
         A2[i+58] = a2;
         a3 += w58 * z3;
         A3[i+58] = a3;
         a4 += w58 * z4;
         A4[i+58] = a4;
         a5 += w58 * z5;
         A5[i+58] = a5;
         a6 += w58 * z6;
         A6[i+58] = a6;
         a7 += w58 * z7;
         A7[i+58] = a7;
         a8 += w58 * z8;
         A8[i+58] = a8;
         a9 += w58 * z9;
         A9[i+58] = a9;
         a10 += w58 * z10;
         A10[i+58] = a10;
         a11 += w58 * z11;
         A11[i+58] = a11;
         a0 = A0[i+59];
         a0 += x59 * y0;
         a1 = A1[i+59];
         a1 += x59 * y1;
         a2 = A2[i+59];
         a2 += x59 * y2;
         a3 = A3[i+59];
         a3 += x59 * y3;
         a4 = A4[i+59];
         a4 += x59 * y4;
         a5 = A5[i+59];
         a5 += x59 * y5;
         a6 = A6[i+59];
         a6 += x59 * y6;
         a7 = A7[i+59];
         a7 += x59 * y7;
         a8 = A8[i+59];
         a8 += x59 * y8;
         a9 = A9[i+59];
         a9 += x59 * y9;
         a10 = A10[i+59];
         a10 += x59 * y10;
         a11 = A11[i+59];
         a11 += x59 * y11;
         a0 += w59 * z0;
         A0[i+59] = a0;
         a1 += w59 * z1;
         A1[i+59] = a1;
         a2 += w59 * z2;
         A2[i+59] = a2;
         a3 += w59 * z3;
         A3[i+59] = a3;
         a4 += w59 * z4;
         A4[i+59] = a4;
         a5 += w59 * z5;
         A5[i+59] = a5;
         a6 += w59 * z6;
         A6[i+59] = a6;
         a7 += w59 * z7;
         A7[i+59] = a7;
         a8 += w59 * z8;
         A8[i+59] = a8;
         a9 += w59 * z9;
         A9[i+59] = a9;
         a10 += w59 * z10;
         A10[i+59] = a10;
         a11 += w59 * z11;
         A11[i+59] = a11;
         a0 = A0[i+60];
         a0 += x60 * y0;
         a1 = A1[i+60];
         a1 += x60 * y1;
         a2 = A2[i+60];
         a2 += x60 * y2;
         a3 = A3[i+60];
         a3 += x60 * y3;
         a4 = A4[i+60];
         a4 += x60 * y4;
         a5 = A5[i+60];
         a5 += x60 * y5;
         a6 = A6[i+60];
         a6 += x60 * y6;
         a7 = A7[i+60];
         a7 += x60 * y7;
         a8 = A8[i+60];
         a8 += x60 * y8;
         a9 = A9[i+60];
         a9 += x60 * y9;
         a10 = A10[i+60];
         a10 += x60 * y10;
         a11 = A11[i+60];
         a11 += x60 * y11;
         a0 += w60 * z0;
         A0[i+60] = a0;
         a1 += w60 * z1;
         A1[i+60] = a1;
         a2 += w60 * z2;
         A2[i+60] = a2;
         a3 += w60 * z3;
         A3[i+60] = a3;
         a4 += w60 * z4;
         A4[i+60] = a4;
         a5 += w60 * z5;
         A5[i+60] = a5;
         a6 += w60 * z6;
         A6[i+60] = a6;
         a7 += w60 * z7;
         A7[i+60] = a7;
         a8 += w60 * z8;
         A8[i+60] = a8;
         a9 += w60 * z9;
         A9[i+60] = a9;
         a10 += w60 * z10;
         A10[i+60] = a10;
         a11 += w60 * z11;
         A11[i+60] = a11;
         a0 = A0[i+61];
         a0 += x61 * y0;
         a1 = A1[i+61];
         a1 += x61 * y1;
         a2 = A2[i+61];
         a2 += x61 * y2;
         a3 = A3[i+61];
         a3 += x61 * y3;
         a4 = A4[i+61];
         a4 += x61 * y4;
         a5 = A5[i+61];
         a5 += x61 * y5;
         a6 = A6[i+61];
         a6 += x61 * y6;
         a7 = A7[i+61];
         a7 += x61 * y7;
         a8 = A8[i+61];
         a8 += x61 * y8;
         a9 = A9[i+61];
         a9 += x61 * y9;
         a10 = A10[i+61];
         a10 += x61 * y10;
         a11 = A11[i+61];
         a11 += x61 * y11;
         a0 += w61 * z0;
         A0[i+61] = a0;
         a1 += w61 * z1;
         A1[i+61] = a1;
         a2 += w61 * z2;
         A2[i+61] = a2;
         a3 += w61 * z3;
         A3[i+61] = a3;
         a4 += w61 * z4;
         A4[i+61] = a4;
         a5 += w61 * z5;
         A5[i+61] = a5;
         a6 += w61 * z6;
         A6[i+61] = a6;
         a7 += w61 * z7;
         A7[i+61] = a7;
         a8 += w61 * z8;
         A8[i+61] = a8;
         a9 += w61 * z9;
         A9[i+61] = a9;
         a10 += w61 * z10;
         A10[i+61] = a10;
         a11 += w61 * z11;
         A11[i+61] = a11;
         a0 = A0[i+62];
         a0 += x62 * y0;
         a1 = A1[i+62];
         a1 += x62 * y1;
         a2 = A2[i+62];
         a2 += x62 * y2;
         a3 = A3[i+62];
         a3 += x62 * y3;
         a4 = A4[i+62];
         a4 += x62 * y4;
         a5 = A5[i+62];
         a5 += x62 * y5;
         a6 = A6[i+62];
         a6 += x62 * y6;
         a7 = A7[i+62];
         a7 += x62 * y7;
         a8 = A8[i+62];
         a8 += x62 * y8;
         a9 = A9[i+62];
         a9 += x62 * y9;
         a10 = A10[i+62];
         a10 += x62 * y10;
         a11 = A11[i+62];
         a11 += x62 * y11;
         a0 += w62 * z0;
         A0[i+62] = a0;
         a1 += w62 * z1;
         A1[i+62] = a1;
         a2 += w62 * z2;
         A2[i+62] = a2;
         a3 += w62 * z3;
         A3[i+62] = a3;
         a4 += w62 * z4;
         A4[i+62] = a4;
         a5 += w62 * z5;
         A5[i+62] = a5;
         a6 += w62 * z6;
         A6[i+62] = a6;
         a7 += w62 * z7;
         A7[i+62] = a7;
         a8 += w62 * z8;
         A8[i+62] = a8;
         a9 += w62 * z9;
         A9[i+62] = a9;
         a10 += w62 * z10;
         A10[i+62] = a10;
         a11 += w62 * z11;
         A11[i+62] = a11;
         a0 = A0[i+63];
         a0 += x63 * y0;
         a1 = A1[i+63];
         a1 += x63 * y1;
         a2 = A2[i+63];
         a2 += x63 * y2;
         a3 = A3[i+63];
         a3 += x63 * y3;
         a4 = A4[i+63];
         a4 += x63 * y4;
         a5 = A5[i+63];
         a5 += x63 * y5;
         a6 = A6[i+63];
         a6 += x63 * y6;
         a7 = A7[i+63];
         a7 += x63 * y7;
         a8 = A8[i+63];
         a8 += x63 * y8;
         a9 = A9[i+63];
         a9 += x63 * y9;
         a10 = A10[i+63];
         a10 += x63 * y10;
         a11 = A11[i+63];
         a11 += x63 * y11;
         a0 += w63 * z0;
         A0[i+63] = a0;
         a1 += w63 * z1;
         A1[i+63] = a1;
         a2 += w63 * z2;
         A2[i+63] = a2;
         a3 += w63 * z3;
         A3[i+63] = a3;
         a4 += w63 * z4;
         A4[i+63] = a4;
         a5 += w63 * z5;
         A5[i+63] = a5;
         a6 += w63 * z6;
         A6[i+63] = a6;
         a7 += w63 * z7;
         A7[i+63] = a7;
         a8 += w63 * z8;
         A8[i+63] = a8;
         a9 += w63 * z9;
         A9[i+63] = a9;
         a10 += w63 * z10;
         A10[i+63] = a10;
         a11 += w63 * z11;
         A11[i+63] = a11;
         a0 = A0[i+64];
         a0 += x64 * y0;
         a1 = A1[i+64];
         a1 += x64 * y1;
         a2 = A2[i+64];
         a2 += x64 * y2;
         a3 = A3[i+64];
         a3 += x64 * y3;
         a4 = A4[i+64];
         a4 += x64 * y4;
         a5 = A5[i+64];
         a5 += x64 * y5;
         a6 = A6[i+64];
         a6 += x64 * y6;
         a7 = A7[i+64];
         a7 += x64 * y7;
         a8 = A8[i+64];
         a8 += x64 * y8;
         a9 = A9[i+64];
         a9 += x64 * y9;
         a10 = A10[i+64];
         a10 += x64 * y10;
         a11 = A11[i+64];
         a11 += x64 * y11;
         a0 += w64 * z0;
         prefA(A0);
         A0[i+64] = a0;
         a1 += w64 * z1;
         prefA(A1);
         A1[i+64] = a1;
         a2 += w64 * z2;
         prefA(A2);
         A2[i+64] = a2;
         a3 += w64 * z3;
         prefA(A3);
         A3[i+64] = a3;
         a4 += w64 * z4;
         prefA(A4);
         A4[i+64] = a4;
         a5 += w64 * z5;
         prefA(A5);
         A5[i+64] = a5;
         a6 += w64 * z6;
         prefA(A6);
         A6[i+64] = a6;
         a7 += w64 * z7;
         prefA(A7);
         A7[i+64] = a7;
         a8 += w64 * z8;
         prefA(A8);
         A8[i+64] = a8;
         a9 += w64 * z9;
         prefA(A9);
         A9[i+64] = a9;
         a10 += w64 * z10;
         prefA(A10);
         A10[i+64] = a10;
         a11 += w64 * z11;
         prefA(A11);
         A11[i+64] = a11;
         a0 = A0[i+65];
         a0 += x65 * y0;
         a1 = A1[i+65];
         a1 += x65 * y1;
         a2 = A2[i+65];
         a2 += x65 * y2;
         a3 = A3[i+65];
         a3 += x65 * y3;
         a4 = A4[i+65];
         a4 += x65 * y4;
         a5 = A5[i+65];
         a5 += x65 * y5;
         a6 = A6[i+65];
         a6 += x65 * y6;
         a7 = A7[i+65];
         a7 += x65 * y7;
         a8 = A8[i+65];
         a8 += x65 * y8;
         a9 = A9[i+65];
         a9 += x65 * y9;
         a10 = A10[i+65];
         a10 += x65 * y10;
         a11 = A11[i+65];
         a11 += x65 * y11;
         a0 += w65 * z0;
         A0[i+65] = a0;
         a1 += w65 * z1;
         A1[i+65] = a1;
         a2 += w65 * z2;
         A2[i+65] = a2;
         a3 += w65 * z3;
         A3[i+65] = a3;
         a4 += w65 * z4;
         A4[i+65] = a4;
         a5 += w65 * z5;
         A5[i+65] = a5;
         a6 += w65 * z6;
         A6[i+65] = a6;
         a7 += w65 * z7;
         A7[i+65] = a7;
         a8 += w65 * z8;
         A8[i+65] = a8;
         a9 += w65 * z9;
         A9[i+65] = a9;
         a10 += w65 * z10;
         A10[i+65] = a10;
         a11 += w65 * z11;
         A11[i+65] = a11;
         a0 = A0[i+66];
         a0 += x66 * y0;
         a1 = A1[i+66];
         a1 += x66 * y1;
         a2 = A2[i+66];
         a2 += x66 * y2;
         a3 = A3[i+66];
         a3 += x66 * y3;
         a4 = A4[i+66];
         a4 += x66 * y4;
         a5 = A5[i+66];
         a5 += x66 * y5;
         a6 = A6[i+66];
         a6 += x66 * y6;
         a7 = A7[i+66];
         a7 += x66 * y7;
         a8 = A8[i+66];
         a8 += x66 * y8;
         a9 = A9[i+66];
         a9 += x66 * y9;
         a10 = A10[i+66];
         a10 += x66 * y10;
         a11 = A11[i+66];
         a11 += x66 * y11;
         a0 += w66 * z0;
         A0[i+66] = a0;
         a1 += w66 * z1;
         A1[i+66] = a1;
         a2 += w66 * z2;
         A2[i+66] = a2;
         a3 += w66 * z3;
         A3[i+66] = a3;
         a4 += w66 * z4;
         A4[i+66] = a4;
         a5 += w66 * z5;
         A5[i+66] = a5;
         a6 += w66 * z6;
         A6[i+66] = a6;
         a7 += w66 * z7;
         A7[i+66] = a7;
         a8 += w66 * z8;
         A8[i+66] = a8;
         a9 += w66 * z9;
         A9[i+66] = a9;
         a10 += w66 * z10;
         A10[i+66] = a10;
         a11 += w66 * z11;
         A11[i+66] = a11;
         a0 = A0[i+67];
         a0 += x67 * y0;
         a1 = A1[i+67];
         a1 += x67 * y1;
         a2 = A2[i+67];
         a2 += x67 * y2;
         a3 = A3[i+67];
         a3 += x67 * y3;
         a4 = A4[i+67];
         a4 += x67 * y4;
         a5 = A5[i+67];
         a5 += x67 * y5;
         a6 = A6[i+67];
         a6 += x67 * y6;
         a7 = A7[i+67];
         a7 += x67 * y7;
         a8 = A8[i+67];
         a8 += x67 * y8;
         a9 = A9[i+67];
         a9 += x67 * y9;
         a10 = A10[i+67];
         a10 += x67 * y10;
         a11 = A11[i+67];
         a11 += x67 * y11;
         a0 += w67 * z0;
         A0[i+67] = a0;
         a1 += w67 * z1;
         A1[i+67] = a1;
         a2 += w67 * z2;
         A2[i+67] = a2;
         a3 += w67 * z3;
         A3[i+67] = a3;
         a4 += w67 * z4;
         A4[i+67] = a4;
         a5 += w67 * z5;
         A5[i+67] = a5;
         a6 += w67 * z6;
         A6[i+67] = a6;
         a7 += w67 * z7;
         A7[i+67] = a7;
         a8 += w67 * z8;
         A8[i+67] = a8;
         a9 += w67 * z9;
         A9[i+67] = a9;
         a10 += w67 * z10;
         A10[i+67] = a10;
         a11 += w67 * z11;
         A11[i+67] = a11;
         a0 = A0[i+68];
         a0 += x68 * y0;
         a1 = A1[i+68];
         a1 += x68 * y1;
         a2 = A2[i+68];
         a2 += x68 * y2;
         a3 = A3[i+68];
         a3 += x68 * y3;
         a4 = A4[i+68];
         a4 += x68 * y4;
         a5 = A5[i+68];
         a5 += x68 * y5;
         a6 = A6[i+68];
         a6 += x68 * y6;
         a7 = A7[i+68];
         a7 += x68 * y7;
         a8 = A8[i+68];
         a8 += x68 * y8;
         a9 = A9[i+68];
         a9 += x68 * y9;
         a10 = A10[i+68];
         a10 += x68 * y10;
         a11 = A11[i+68];
         a11 += x68 * y11;
         a0 += w68 * z0;
         A0[i+68] = a0;
         a1 += w68 * z1;
         A1[i+68] = a1;
         a2 += w68 * z2;
         A2[i+68] = a2;
         a3 += w68 * z3;
         A3[i+68] = a3;
         a4 += w68 * z4;
         A4[i+68] = a4;
         a5 += w68 * z5;
         A5[i+68] = a5;
         a6 += w68 * z6;
         A6[i+68] = a6;
         a7 += w68 * z7;
         A7[i+68] = a7;
         a8 += w68 * z8;
         A8[i+68] = a8;
         a9 += w68 * z9;
         A9[i+68] = a9;
         a10 += w68 * z10;
         A10[i+68] = a10;
         a11 += w68 * z11;
         A11[i+68] = a11;
         a0 = A0[i+69];
         a0 += x69 * y0;
         a1 = A1[i+69];
         a1 += x69 * y1;
         a2 = A2[i+69];
         a2 += x69 * y2;
         a3 = A3[i+69];
         a3 += x69 * y3;
         a4 = A4[i+69];
         a4 += x69 * y4;
         a5 = A5[i+69];
         a5 += x69 * y5;
         a6 = A6[i+69];
         a6 += x69 * y6;
         a7 = A7[i+69];
         a7 += x69 * y7;
         a8 = A8[i+69];
         a8 += x69 * y8;
         a9 = A9[i+69];
         a9 += x69 * y9;
         a10 = A10[i+69];
         a10 += x69 * y10;
         a11 = A11[i+69];
         a11 += x69 * y11;
         a0 += w69 * z0;
         A0[i+69] = a0;
         a1 += w69 * z1;
         A1[i+69] = a1;
         a2 += w69 * z2;
         A2[i+69] = a2;
         a3 += w69 * z3;
         A3[i+69] = a3;
         a4 += w69 * z4;
         A4[i+69] = a4;
         a5 += w69 * z5;
         A5[i+69] = a5;
         a6 += w69 * z6;
         A6[i+69] = a6;
         a7 += w69 * z7;
         A7[i+69] = a7;
         a8 += w69 * z8;
         A8[i+69] = a8;
         a9 += w69 * z9;
         A9[i+69] = a9;
         a10 += w69 * z10;
         A10[i+69] = a10;
         a11 += w69 * z11;
         A11[i+69] = a11;
         a0 = A0[i+70];
         a0 += x70 * y0;
         a1 = A1[i+70];
         a1 += x70 * y1;
         a2 = A2[i+70];
         a2 += x70 * y2;
         a3 = A3[i+70];
         a3 += x70 * y3;
         a4 = A4[i+70];
         a4 += x70 * y4;
         a5 = A5[i+70];
         a5 += x70 * y5;
         a6 = A6[i+70];
         a6 += x70 * y6;
         a7 = A7[i+70];
         a7 += x70 * y7;
         a8 = A8[i+70];
         a8 += x70 * y8;
         a9 = A9[i+70];
         a9 += x70 * y9;
         a10 = A10[i+70];
         a10 += x70 * y10;
         a11 = A11[i+70];
         a11 += x70 * y11;
         a0 += w70 * z0;
         A0[i+70] = a0;
         a1 += w70 * z1;
         A1[i+70] = a1;
         a2 += w70 * z2;
         A2[i+70] = a2;
         a3 += w70 * z3;
         A3[i+70] = a3;
         a4 += w70 * z4;
         A4[i+70] = a4;
         a5 += w70 * z5;
         A5[i+70] = a5;
         a6 += w70 * z6;
         A6[i+70] = a6;
         a7 += w70 * z7;
         A7[i+70] = a7;
         a8 += w70 * z8;
         A8[i+70] = a8;
         a9 += w70 * z9;
         A9[i+70] = a9;
         a10 += w70 * z10;
         A10[i+70] = a10;
         a11 += w70 * z11;
         A11[i+70] = a11;
         a0 = A0[i+71];
         a0 += x71 * y0;
         a1 = A1[i+71];
         a1 += x71 * y1;
         a2 = A2[i+71];
         a2 += x71 * y2;
         a3 = A3[i+71];
         a3 += x71 * y3;
         a4 = A4[i+71];
         a4 += x71 * y4;
         a5 = A5[i+71];
         a5 += x71 * y5;
         a6 = A6[i+71];
         a6 += x71 * y6;
         a7 = A7[i+71];
         a7 += x71 * y7;
         a8 = A8[i+71];
         a8 += x71 * y8;
         a9 = A9[i+71];
         a9 += x71 * y9;
         a10 = A10[i+71];
         a10 += x71 * y10;
         a11 = A11[i+71];
         a11 += x71 * y11;
         a0 += w71 * z0;
         A0[i+71] = a0;
         a1 += w71 * z1;
         A1[i+71] = a1;
         a2 += w71 * z2;
         A2[i+71] = a2;
         a3 += w71 * z3;
         A3[i+71] = a3;
         a4 += w71 * z4;
         A4[i+71] = a4;
         a5 += w71 * z5;
         A5[i+71] = a5;
         a6 += w71 * z6;
         A6[i+71] = a6;
         a7 += w71 * z7;
         A7[i+71] = a7;
         a8 += w71 * z8;
         A8[i+71] = a8;
         a9 += w71 * z9;
         A9[i+71] = a9;
         a10 += w71 * z10;
         A10[i+71] = a10;
         a11 += w71 * z11;
         A11[i+71] = a11;
         a0 = A0[i+72];
         a0 += x72 * y0;
         a1 = A1[i+72];
         a1 += x72 * y1;
         a2 = A2[i+72];
         a2 += x72 * y2;
         a3 = A3[i+72];
         a3 += x72 * y3;
         a4 = A4[i+72];
         a4 += x72 * y4;
         a5 = A5[i+72];
         a5 += x72 * y5;
         a6 = A6[i+72];
         a6 += x72 * y6;
         a7 = A7[i+72];
         a7 += x72 * y7;
         a8 = A8[i+72];
         a8 += x72 * y8;
         a9 = A9[i+72];
         a9 += x72 * y9;
         a10 = A10[i+72];
         a10 += x72 * y10;
         a11 = A11[i+72];
         a11 += x72 * y11;
         a0 += w72 * z0;
         A0[i+72] = a0;
         a1 += w72 * z1;
         A1[i+72] = a1;
         a2 += w72 * z2;
         A2[i+72] = a2;
         a3 += w72 * z3;
         A3[i+72] = a3;
         a4 += w72 * z4;
         A4[i+72] = a4;
         a5 += w72 * z5;
         A5[i+72] = a5;
         a6 += w72 * z6;
         A6[i+72] = a6;
         a7 += w72 * z7;
         A7[i+72] = a7;
         a8 += w72 * z8;
         A8[i+72] = a8;
         a9 += w72 * z9;
         A9[i+72] = a9;
         a10 += w72 * z10;
         A10[i+72] = a10;
         a11 += w72 * z11;
         A11[i+72] = a11;
         a0 = A0[i+73];
         a0 += x73 * y0;
         a1 = A1[i+73];
         a1 += x73 * y1;
         a2 = A2[i+73];
         a2 += x73 * y2;
         a3 = A3[i+73];
         a3 += x73 * y3;
         a4 = A4[i+73];
         a4 += x73 * y4;
         a5 = A5[i+73];
         a5 += x73 * y5;
         a6 = A6[i+73];
         a6 += x73 * y6;
         a7 = A7[i+73];
         a7 += x73 * y7;
         a8 = A8[i+73];
         a8 += x73 * y8;
         a9 = A9[i+73];
         a9 += x73 * y9;
         a10 = A10[i+73];
         a10 += x73 * y10;
         a11 = A11[i+73];
         a11 += x73 * y11;
         a0 += w73 * z0;
         A0[i+73] = a0;
         a1 += w73 * z1;
         A1[i+73] = a1;
         a2 += w73 * z2;
         A2[i+73] = a2;
         a3 += w73 * z3;
         A3[i+73] = a3;
         a4 += w73 * z4;
         A4[i+73] = a4;
         a5 += w73 * z5;
         A5[i+73] = a5;
         a6 += w73 * z6;
         A6[i+73] = a6;
         a7 += w73 * z7;
         A7[i+73] = a7;
         a8 += w73 * z8;
         A8[i+73] = a8;
         a9 += w73 * z9;
         A9[i+73] = a9;
         a10 += w73 * z10;
         A10[i+73] = a10;
         a11 += w73 * z11;
         A11[i+73] = a11;
         a0 = A0[i+74];
         a0 += x74 * y0;
         a1 = A1[i+74];
         a1 += x74 * y1;
         a2 = A2[i+74];
         a2 += x74 * y2;
         a3 = A3[i+74];
         a3 += x74 * y3;
         a4 = A4[i+74];
         a4 += x74 * y4;
         a5 = A5[i+74];
         a5 += x74 * y5;
         a6 = A6[i+74];
         a6 += x74 * y6;
         a7 = A7[i+74];
         a7 += x74 * y7;
         a8 = A8[i+74];
         a8 += x74 * y8;
         a9 = A9[i+74];
         a9 += x74 * y9;
         a10 = A10[i+74];
         a10 += x74 * y10;
         a11 = A11[i+74];
         a11 += x74 * y11;
         a0 += w74 * z0;
         A0[i+74] = a0;
         a1 += w74 * z1;
         A1[i+74] = a1;
         a2 += w74 * z2;
         A2[i+74] = a2;
         a3 += w74 * z3;
         A3[i+74] = a3;
         a4 += w74 * z4;
         A4[i+74] = a4;
         a5 += w74 * z5;
         A5[i+74] = a5;
         a6 += w74 * z6;
         A6[i+74] = a6;
         a7 += w74 * z7;
         A7[i+74] = a7;
         a8 += w74 * z8;
         A8[i+74] = a8;
         a9 += w74 * z9;
         A9[i+74] = a9;
         a10 += w74 * z10;
         A10[i+74] = a10;
         a11 += w74 * z11;
         A11[i+74] = a11;
         a0 = A0[i+75];
         a0 += x75 * y0;
         a1 = A1[i+75];
         a1 += x75 * y1;
         a2 = A2[i+75];
         a2 += x75 * y2;
         a3 = A3[i+75];
         a3 += x75 * y3;
         a4 = A4[i+75];
         a4 += x75 * y4;
         a5 = A5[i+75];
         a5 += x75 * y5;
         a6 = A6[i+75];
         a6 += x75 * y6;
         a7 = A7[i+75];
         a7 += x75 * y7;
         a8 = A8[i+75];
         a8 += x75 * y8;
         a9 = A9[i+75];
         a9 += x75 * y9;
         a10 = A10[i+75];
         a10 += x75 * y10;
         a11 = A11[i+75];
         a11 += x75 * y11;
         a0 += w75 * z0;
         A0[i+75] = a0;
         a1 += w75 * z1;
         A1[i+75] = a1;
         a2 += w75 * z2;
         A2[i+75] = a2;
         a3 += w75 * z3;
         A3[i+75] = a3;
         a4 += w75 * z4;
         A4[i+75] = a4;
         a5 += w75 * z5;
         A5[i+75] = a5;
         a6 += w75 * z6;
         A6[i+75] = a6;
         a7 += w75 * z7;
         A7[i+75] = a7;
         a8 += w75 * z8;
         A8[i+75] = a8;
         a9 += w75 * z9;
         A9[i+75] = a9;
         a10 += w75 * z10;
         A10[i+75] = a10;
         a11 += w75 * z11;
         A11[i+75] = a11;
         a0 = A0[i+76];
         a0 += x76 * y0;
         a1 = A1[i+76];
         a1 += x76 * y1;
         a2 = A2[i+76];
         a2 += x76 * y2;
         a3 = A3[i+76];
         a3 += x76 * y3;
         a4 = A4[i+76];
         a4 += x76 * y4;
         a5 = A5[i+76];
         a5 += x76 * y5;
         a6 = A6[i+76];
         a6 += x76 * y6;
         a7 = A7[i+76];
         a7 += x76 * y7;
         a8 = A8[i+76];
         a8 += x76 * y8;
         a9 = A9[i+76];
         a9 += x76 * y9;
         a10 = A10[i+76];
         a10 += x76 * y10;
         a11 = A11[i+76];
         a11 += x76 * y11;
         a0 += w76 * z0;
         A0[i+76] = a0;
         a1 += w76 * z1;
         A1[i+76] = a1;
         a2 += w76 * z2;
         A2[i+76] = a2;
         a3 += w76 * z3;
         A3[i+76] = a3;
         a4 += w76 * z4;
         A4[i+76] = a4;
         a5 += w76 * z5;
         A5[i+76] = a5;
         a6 += w76 * z6;
         A6[i+76] = a6;
         a7 += w76 * z7;
         A7[i+76] = a7;
         a8 += w76 * z8;
         A8[i+76] = a8;
         a9 += w76 * z9;
         A9[i+76] = a9;
         a10 += w76 * z10;
         A10[i+76] = a10;
         a11 += w76 * z11;
         A11[i+76] = a11;
         a0 = A0[i+77];
         a0 += x77 * y0;
         a1 = A1[i+77];
         a1 += x77 * y1;
         a2 = A2[i+77];
         a2 += x77 * y2;
         a3 = A3[i+77];
         a3 += x77 * y3;
         a4 = A4[i+77];
         a4 += x77 * y4;
         a5 = A5[i+77];
         a5 += x77 * y5;
         a6 = A6[i+77];
         a6 += x77 * y6;
         a7 = A7[i+77];
         a7 += x77 * y7;
         a8 = A8[i+77];
         a8 += x77 * y8;
         a9 = A9[i+77];
         a9 += x77 * y9;
         a10 = A10[i+77];
         a10 += x77 * y10;
         a11 = A11[i+77];
         a11 += x77 * y11;
         a0 += w77 * z0;
         A0[i+77] = a0;
         a1 += w77 * z1;
         A1[i+77] = a1;
         a2 += w77 * z2;
         A2[i+77] = a2;
         a3 += w77 * z3;
         A3[i+77] = a3;
         a4 += w77 * z4;
         A4[i+77] = a4;
         a5 += w77 * z5;
         A5[i+77] = a5;
         a6 += w77 * z6;
         A6[i+77] = a6;
         a7 += w77 * z7;
         A7[i+77] = a7;
         a8 += w77 * z8;
         A8[i+77] = a8;
         a9 += w77 * z9;
         A9[i+77] = a9;
         a10 += w77 * z10;
         A10[i+77] = a10;
         a11 += w77 * z11;
         A11[i+77] = a11;
         a0 = A0[i+78];
         a0 += x78 * y0;
         a1 = A1[i+78];
         a1 += x78 * y1;
         a2 = A2[i+78];
         a2 += x78 * y2;
         a3 = A3[i+78];
         a3 += x78 * y3;
         a4 = A4[i+78];
         a4 += x78 * y4;
         a5 = A5[i+78];
         a5 += x78 * y5;
         a6 = A6[i+78];
         a6 += x78 * y6;
         a7 = A7[i+78];
         a7 += x78 * y7;
         a8 = A8[i+78];
         a8 += x78 * y8;
         a9 = A9[i+78];
         a9 += x78 * y9;
         a10 = A10[i+78];
         a10 += x78 * y10;
         a11 = A11[i+78];
         a11 += x78 * y11;
         a0 += w78 * z0;
         A0[i+78] = a0;
         a1 += w78 * z1;
         A1[i+78] = a1;
         a2 += w78 * z2;
         A2[i+78] = a2;
         a3 += w78 * z3;
         A3[i+78] = a3;
         a4 += w78 * z4;
         A4[i+78] = a4;
         a5 += w78 * z5;
         A5[i+78] = a5;
         a6 += w78 * z6;
         A6[i+78] = a6;
         a7 += w78 * z7;
         A7[i+78] = a7;
         a8 += w78 * z8;
         A8[i+78] = a8;
         a9 += w78 * z9;
         A9[i+78] = a9;
         a10 += w78 * z10;
         A10[i+78] = a10;
         a11 += w78 * z11;
         A11[i+78] = a11;
         a0 = A0[i+79];
         a0 += x79 * y0;
         a1 = A1[i+79];
         a1 += x79 * y1;
         a2 = A2[i+79];
         a2 += x79 * y2;
         a3 = A3[i+79];
         a3 += x79 * y3;
         a4 = A4[i+79];
         a4 += x79 * y4;
         a5 = A5[i+79];
         a5 += x79 * y5;
         a6 = A6[i+79];
         a6 += x79 * y6;
         a7 = A7[i+79];
         a7 += x79 * y7;
         a8 = A8[i+79];
         a8 += x79 * y8;
         a9 = A9[i+79];
         a9 += x79 * y9;
         a10 = A10[i+79];
         a10 += x79 * y10;
         a11 = A11[i+79];
         a11 += x79 * y11;
         a0 += w79 * z0;
         A0[i+79] = a0;
         a1 += w79 * z1;
         A1[i+79] = a1;
         a2 += w79 * z2;
         A2[i+79] = a2;
         a3 += w79 * z3;
         A3[i+79] = a3;
         a4 += w79 * z4;
         A4[i+79] = a4;
         a5 += w79 * z5;
         A5[i+79] = a5;
         a6 += w79 * z6;
         A6[i+79] = a6;
         a7 += w79 * z7;
         A7[i+79] = a7;
         a8 += w79 * z8;
         A8[i+79] = a8;
         a9 += w79 * z9;
         A9[i+79] = a9;
         a10 += w79 * z10;
         A10[i+79] = a10;
         a11 += w79 * z11;
         A11[i+79] = a11;
         a0 = A0[i+80];
         a0 += x80 * y0;
         a1 = A1[i+80];
         a1 += x80 * y1;
         a2 = A2[i+80];
         a2 += x80 * y2;
         a3 = A3[i+80];
         a3 += x80 * y3;
         a4 = A4[i+80];
         a4 += x80 * y4;
         a5 = A5[i+80];
         a5 += x80 * y5;
         a6 = A6[i+80];
         a6 += x80 * y6;
         a7 = A7[i+80];
         a7 += x80 * y7;
         a8 = A8[i+80];
         a8 += x80 * y8;
         a9 = A9[i+80];
         a9 += x80 * y9;
         a10 = A10[i+80];
         a10 += x80 * y10;
         a11 = A11[i+80];
         a11 += x80 * y11;
         a0 += w80 * z0;
         prefA(A0);
         A0[i+80] = a0;
         a1 += w80 * z1;
         prefA(A1);
         A1[i+80] = a1;
         a2 += w80 * z2;
         prefA(A2);
         A2[i+80] = a2;
         a3 += w80 * z3;
         prefA(A3);
         A3[i+80] = a3;
         a4 += w80 * z4;
         prefA(A4);
         A4[i+80] = a4;
         a5 += w80 * z5;
         prefA(A5);
         A5[i+80] = a5;
         a6 += w80 * z6;
         prefA(A6);
         A6[i+80] = a6;
         a7 += w80 * z7;
         prefA(A7);
         A7[i+80] = a7;
         a8 += w80 * z8;
         prefA(A8);
         A8[i+80] = a8;
         a9 += w80 * z9;
         prefA(A9);
         A9[i+80] = a9;
         a10 += w80 * z10;
         prefA(A10);
         A10[i+80] = a10;
         a11 += w80 * z11;
         prefA(A11);
         A11[i+80] = a11;
         a0 = A0[i+81];
         a0 += x81 * y0;
         a1 = A1[i+81];
         a1 += x81 * y1;
         a2 = A2[i+81];
         a2 += x81 * y2;
         a3 = A3[i+81];
         a3 += x81 * y3;
         a4 = A4[i+81];
         a4 += x81 * y4;
         a5 = A5[i+81];
         a5 += x81 * y5;
         a6 = A6[i+81];
         a6 += x81 * y6;
         a7 = A7[i+81];
         a7 += x81 * y7;
         a8 = A8[i+81];
         a8 += x81 * y8;
         a9 = A9[i+81];
         a9 += x81 * y9;
         a10 = A10[i+81];
         a10 += x81 * y10;
         a11 = A11[i+81];
         a11 += x81 * y11;
         a0 += w81 * z0;
         A0[i+81] = a0;
         a1 += w81 * z1;
         A1[i+81] = a1;
         a2 += w81 * z2;
         A2[i+81] = a2;
         a3 += w81 * z3;
         A3[i+81] = a3;
         a4 += w81 * z4;
         A4[i+81] = a4;
         a5 += w81 * z5;
         A5[i+81] = a5;
         a6 += w81 * z6;
         A6[i+81] = a6;
         a7 += w81 * z7;
         A7[i+81] = a7;
         a8 += w81 * z8;
         A8[i+81] = a8;
         a9 += w81 * z9;
         A9[i+81] = a9;
         a10 += w81 * z10;
         A10[i+81] = a10;
         a11 += w81 * z11;
         A11[i+81] = a11;
         a0 = A0[i+82];
         a0 += x82 * y0;
         a1 = A1[i+82];
         a1 += x82 * y1;
         a2 = A2[i+82];
         a2 += x82 * y2;
         a3 = A3[i+82];
         a3 += x82 * y3;
         a4 = A4[i+82];
         a4 += x82 * y4;
         a5 = A5[i+82];
         a5 += x82 * y5;
         a6 = A6[i+82];
         a6 += x82 * y6;
         a7 = A7[i+82];
         a7 += x82 * y7;
         a8 = A8[i+82];
         a8 += x82 * y8;
         a9 = A9[i+82];
         a9 += x82 * y9;
         a10 = A10[i+82];
         a10 += x82 * y10;
         a11 = A11[i+82];
         a11 += x82 * y11;
         a0 += w82 * z0;
         A0[i+82] = a0;
         a1 += w82 * z1;
         A1[i+82] = a1;
         a2 += w82 * z2;
         A2[i+82] = a2;
         a3 += w82 * z3;
         A3[i+82] = a3;
         a4 += w82 * z4;
         A4[i+82] = a4;
         a5 += w82 * z5;
         A5[i+82] = a5;
         a6 += w82 * z6;
         A6[i+82] = a6;
         a7 += w82 * z7;
         A7[i+82] = a7;
         a8 += w82 * z8;
         A8[i+82] = a8;
         a9 += w82 * z9;
         A9[i+82] = a9;
         a10 += w82 * z10;
         A10[i+82] = a10;
         a11 += w82 * z11;
         A11[i+82] = a11;
         a0 = A0[i+83];
         a0 += x83 * y0;
         a1 = A1[i+83];
         a1 += x83 * y1;
         a2 = A2[i+83];
         a2 += x83 * y2;
         a3 = A3[i+83];
         a3 += x83 * y3;
         a4 = A4[i+83];
         a4 += x83 * y4;
         a5 = A5[i+83];
         a5 += x83 * y5;
         a6 = A6[i+83];
         a6 += x83 * y6;
         a7 = A7[i+83];
         a7 += x83 * y7;
         a8 = A8[i+83];
         a8 += x83 * y8;
         a9 = A9[i+83];
         a9 += x83 * y9;
         a10 = A10[i+83];
         a10 += x83 * y10;
         a11 = A11[i+83];
         a11 += x83 * y11;
         a0 += w83 * z0;
         A0[i+83] = a0;
         a1 += w83 * z1;
         A1[i+83] = a1;
         a2 += w83 * z2;
         A2[i+83] = a2;
         a3 += w83 * z3;
         A3[i+83] = a3;
         a4 += w83 * z4;
         A4[i+83] = a4;
         a5 += w83 * z5;
         A5[i+83] = a5;
         a6 += w83 * z6;
         A6[i+83] = a6;
         a7 += w83 * z7;
         A7[i+83] = a7;
         a8 += w83 * z8;
         A8[i+83] = a8;
         a9 += w83 * z9;
         A9[i+83] = a9;
         a10 += w83 * z10;
         A10[i+83] = a10;
         a11 += w83 * z11;
         A11[i+83] = a11;
         a0 = A0[i+84];
         a0 += x84 * y0;
         a1 = A1[i+84];
         a1 += x84 * y1;
         a2 = A2[i+84];
         a2 += x84 * y2;
         a3 = A3[i+84];
         a3 += x84 * y3;
         a4 = A4[i+84];
         a4 += x84 * y4;
         a5 = A5[i+84];
         a5 += x84 * y5;
         a6 = A6[i+84];
         a6 += x84 * y6;
         a7 = A7[i+84];
         a7 += x84 * y7;
         a8 = A8[i+84];
         a8 += x84 * y8;
         a9 = A9[i+84];
         a9 += x84 * y9;
         a10 = A10[i+84];
         a10 += x84 * y10;
         a11 = A11[i+84];
         a11 += x84 * y11;
         a0 += w84 * z0;
         A0[i+84] = a0;
         a1 += w84 * z1;
         A1[i+84] = a1;
         a2 += w84 * z2;
         A2[i+84] = a2;
         a3 += w84 * z3;
         A3[i+84] = a3;
         a4 += w84 * z4;
         A4[i+84] = a4;
         a5 += w84 * z5;
         A5[i+84] = a5;
         a6 += w84 * z6;
         A6[i+84] = a6;
         a7 += w84 * z7;
         A7[i+84] = a7;
         a8 += w84 * z8;
         A8[i+84] = a8;
         a9 += w84 * z9;
         A9[i+84] = a9;
         a10 += w84 * z10;
         A10[i+84] = a10;
         a11 += w84 * z11;
         A11[i+84] = a11;
         a0 = A0[i+85];
         a0 += x85 * y0;
         a1 = A1[i+85];
         a1 += x85 * y1;
         a2 = A2[i+85];
         a2 += x85 * y2;
         a3 = A3[i+85];
         a3 += x85 * y3;
         a4 = A4[i+85];
         a4 += x85 * y4;
         a5 = A5[i+85];
         a5 += x85 * y5;
         a6 = A6[i+85];
         a6 += x85 * y6;
         a7 = A7[i+85];
         a7 += x85 * y7;
         a8 = A8[i+85];
         a8 += x85 * y8;
         a9 = A9[i+85];
         a9 += x85 * y9;
         a10 = A10[i+85];
         a10 += x85 * y10;
         a11 = A11[i+85];
         a11 += x85 * y11;
         a0 += w85 * z0;
         A0[i+85] = a0;
         a1 += w85 * z1;
         A1[i+85] = a1;
         a2 += w85 * z2;
         A2[i+85] = a2;
         a3 += w85 * z3;
         A3[i+85] = a3;
         a4 += w85 * z4;
         A4[i+85] = a4;
         a5 += w85 * z5;
         A5[i+85] = a5;
         a6 += w85 * z6;
         A6[i+85] = a6;
         a7 += w85 * z7;
         A7[i+85] = a7;
         a8 += w85 * z8;
         A8[i+85] = a8;
         a9 += w85 * z9;
         A9[i+85] = a9;
         a10 += w85 * z10;
         A10[i+85] = a10;
         a11 += w85 * z11;
         A11[i+85] = a11;
         a0 = A0[i+86];
         a0 += x86 * y0;
         a1 = A1[i+86];
         a1 += x86 * y1;
         a2 = A2[i+86];
         a2 += x86 * y2;
         a3 = A3[i+86];
         a3 += x86 * y3;
         a4 = A4[i+86];
         a4 += x86 * y4;
         a5 = A5[i+86];
         a5 += x86 * y5;
         a6 = A6[i+86];
         a6 += x86 * y6;
         a7 = A7[i+86];
         a7 += x86 * y7;
         a8 = A8[i+86];
         a8 += x86 * y8;
         a9 = A9[i+86];
         a9 += x86 * y9;
         a10 = A10[i+86];
         a10 += x86 * y10;
         a11 = A11[i+86];
         a11 += x86 * y11;
         a0 += w86 * z0;
         A0[i+86] = a0;
         a1 += w86 * z1;
         A1[i+86] = a1;
         a2 += w86 * z2;
         A2[i+86] = a2;
         a3 += w86 * z3;
         A3[i+86] = a3;
         a4 += w86 * z4;
         A4[i+86] = a4;
         a5 += w86 * z5;
         A5[i+86] = a5;
         a6 += w86 * z6;
         A6[i+86] = a6;
         a7 += w86 * z7;
         A7[i+86] = a7;
         a8 += w86 * z8;
         A8[i+86] = a8;
         a9 += w86 * z9;
         A9[i+86] = a9;
         a10 += w86 * z10;
         A10[i+86] = a10;
         a11 += w86 * z11;
         A11[i+86] = a11;
         a0 = A0[i+87];
         a0 += x87 * y0;
         a1 = A1[i+87];
         a1 += x87 * y1;
         a2 = A2[i+87];
         a2 += x87 * y2;
         a3 = A3[i+87];
         a3 += x87 * y3;
         a4 = A4[i+87];
         a4 += x87 * y4;
         a5 = A5[i+87];
         a5 += x87 * y5;
         a6 = A6[i+87];
         a6 += x87 * y6;
         a7 = A7[i+87];
         a7 += x87 * y7;
         a8 = A8[i+87];
         a8 += x87 * y8;
         a9 = A9[i+87];
         a9 += x87 * y9;
         a10 = A10[i+87];
         a10 += x87 * y10;
         a11 = A11[i+87];
         a11 += x87 * y11;
         a0 += w87 * z0;
         A0[i+87] = a0;
         a1 += w87 * z1;
         A1[i+87] = a1;
         a2 += w87 * z2;
         A2[i+87] = a2;
         a3 += w87 * z3;
         A3[i+87] = a3;
         a4 += w87 * z4;
         A4[i+87] = a4;
         a5 += w87 * z5;
         A5[i+87] = a5;
         a6 += w87 * z6;
         A6[i+87] = a6;
         a7 += w87 * z7;
         A7[i+87] = a7;
         a8 += w87 * z8;
         A8[i+87] = a8;
         a9 += w87 * z9;
         A9[i+87] = a9;
         a10 += w87 * z10;
         A10[i+87] = a10;
         a11 += w87 * z11;
         A11[i+87] = a11;
         a0 = A0[i+88];
         a0 += x88 * y0;
         a1 = A1[i+88];
         a1 += x88 * y1;
         a2 = A2[i+88];
         a2 += x88 * y2;
         a3 = A3[i+88];
         a3 += x88 * y3;
         a4 = A4[i+88];
         a4 += x88 * y4;
         a5 = A5[i+88];
         a5 += x88 * y5;
         a6 = A6[i+88];
         a6 += x88 * y6;
         a7 = A7[i+88];
         a7 += x88 * y7;
         a8 = A8[i+88];
         a8 += x88 * y8;
         a9 = A9[i+88];
         a9 += x88 * y9;
         a10 = A10[i+88];
         a10 += x88 * y10;
         a11 = A11[i+88];
         a11 += x88 * y11;
         a0 += w88 * z0;
         A0[i+88] = a0;
         a1 += w88 * z1;
         A1[i+88] = a1;
         a2 += w88 * z2;
         A2[i+88] = a2;
         a3 += w88 * z3;
         A3[i+88] = a3;
         a4 += w88 * z4;
         A4[i+88] = a4;
         a5 += w88 * z5;
         A5[i+88] = a5;
         a6 += w88 * z6;
         A6[i+88] = a6;
         a7 += w88 * z7;
         A7[i+88] = a7;
         a8 += w88 * z8;
         A8[i+88] = a8;
         a9 += w88 * z9;
         A9[i+88] = a9;
         a10 += w88 * z10;
         A10[i+88] = a10;
         a11 += w88 * z11;
         A11[i+88] = a11;
         a0 = A0[i+89];
         a0 += x89 * y0;
         a1 = A1[i+89];
         a1 += x89 * y1;
         a2 = A2[i+89];
         a2 += x89 * y2;
         a3 = A3[i+89];
         a3 += x89 * y3;
         a4 = A4[i+89];
         a4 += x89 * y4;
         a5 = A5[i+89];
         a5 += x89 * y5;
         a6 = A6[i+89];
         a6 += x89 * y6;
         a7 = A7[i+89];
         a7 += x89 * y7;
         a8 = A8[i+89];
         a8 += x89 * y8;
         a9 = A9[i+89];
         a9 += x89 * y9;
         a10 = A10[i+89];
         a10 += x89 * y10;
         a11 = A11[i+89];
         a11 += x89 * y11;
         a0 += w89 * z0;
         A0[i+89] = a0;
         a1 += w89 * z1;
         A1[i+89] = a1;
         a2 += w89 * z2;
         A2[i+89] = a2;
         a3 += w89 * z3;
         A3[i+89] = a3;
         a4 += w89 * z4;
         A4[i+89] = a4;
         a5 += w89 * z5;
         A5[i+89] = a5;
         a6 += w89 * z6;
         A6[i+89] = a6;
         a7 += w89 * z7;
         A7[i+89] = a7;
         a8 += w89 * z8;
         A8[i+89] = a8;
         a9 += w89 * z9;
         A9[i+89] = a9;
         a10 += w89 * z10;
         A10[i+89] = a10;
         a11 += w89 * z11;
         A11[i+89] = a11;
         a0 = A0[i+90];
         a0 += x90 * y0;
         a1 = A1[i+90];
         a1 += x90 * y1;
         a2 = A2[i+90];
         a2 += x90 * y2;
         a3 = A3[i+90];
         a3 += x90 * y3;
         a4 = A4[i+90];
         a4 += x90 * y4;
         a5 = A5[i+90];
         a5 += x90 * y5;
         a6 = A6[i+90];
         a6 += x90 * y6;
         a7 = A7[i+90];
         a7 += x90 * y7;
         a8 = A8[i+90];
         a8 += x90 * y8;
         a9 = A9[i+90];
         a9 += x90 * y9;
         a10 = A10[i+90];
         a10 += x90 * y10;
         a11 = A11[i+90];
         a11 += x90 * y11;
         a0 += w90 * z0;
         A0[i+90] = a0;
         a1 += w90 * z1;
         A1[i+90] = a1;
         a2 += w90 * z2;
         A2[i+90] = a2;
         a3 += w90 * z3;
         A3[i+90] = a3;
         a4 += w90 * z4;
         A4[i+90] = a4;
         a5 += w90 * z5;
         A5[i+90] = a5;
         a6 += w90 * z6;
         A6[i+90] = a6;
         a7 += w90 * z7;
         A7[i+90] = a7;
         a8 += w90 * z8;
         A8[i+90] = a8;
         a9 += w90 * z9;
         A9[i+90] = a9;
         a10 += w90 * z10;
         A10[i+90] = a10;
         a11 += w90 * z11;
         A11[i+90] = a11;
         a0 = A0[i+91];
         a0 += x91 * y0;
         a1 = A1[i+91];
         a1 += x91 * y1;
         a2 = A2[i+91];
         a2 += x91 * y2;
         a3 = A3[i+91];
         a3 += x91 * y3;
         a4 = A4[i+91];
         a4 += x91 * y4;
         a5 = A5[i+91];
         a5 += x91 * y5;
         a6 = A6[i+91];
         a6 += x91 * y6;
         a7 = A7[i+91];
         a7 += x91 * y7;
         a8 = A8[i+91];
         a8 += x91 * y8;
         a9 = A9[i+91];
         a9 += x91 * y9;
         a10 = A10[i+91];
         a10 += x91 * y10;
         a11 = A11[i+91];
         a11 += x91 * y11;
         a0 += w91 * z0;
         A0[i+91] = a0;
         a1 += w91 * z1;
         A1[i+91] = a1;
         a2 += w91 * z2;
         A2[i+91] = a2;
         a3 += w91 * z3;
         A3[i+91] = a3;
         a4 += w91 * z4;
         A4[i+91] = a4;
         a5 += w91 * z5;
         A5[i+91] = a5;
         a6 += w91 * z6;
         A6[i+91] = a6;
         a7 += w91 * z7;
         A7[i+91] = a7;
         a8 += w91 * z8;
         A8[i+91] = a8;
         a9 += w91 * z9;
         A9[i+91] = a9;
         a10 += w91 * z10;
         A10[i+91] = a10;
         a11 += w91 * z11;
         A11[i+91] = a11;
         a0 = A0[i+92];
         a0 += x92 * y0;
         a1 = A1[i+92];
         a1 += x92 * y1;
         a2 = A2[i+92];
         a2 += x92 * y2;
         a3 = A3[i+92];
         a3 += x92 * y3;
         a4 = A4[i+92];
         a4 += x92 * y4;
         a5 = A5[i+92];
         a5 += x92 * y5;
         a6 = A6[i+92];
         a6 += x92 * y6;
         a7 = A7[i+92];
         a7 += x92 * y7;
         a8 = A8[i+92];
         a8 += x92 * y8;
         a9 = A9[i+92];
         a9 += x92 * y9;
         a10 = A10[i+92];
         a10 += x92 * y10;
         a11 = A11[i+92];
         a11 += x92 * y11;
         a0 += w92 * z0;
         A0[i+92] = a0;
         a1 += w92 * z1;
         A1[i+92] = a1;
         a2 += w92 * z2;
         A2[i+92] = a2;
         a3 += w92 * z3;
         A3[i+92] = a3;
         a4 += w92 * z4;
         A4[i+92] = a4;
         a5 += w92 * z5;
         A5[i+92] = a5;
         a6 += w92 * z6;
         A6[i+92] = a6;
         a7 += w92 * z7;
         A7[i+92] = a7;
         a8 += w92 * z8;
         A8[i+92] = a8;
         a9 += w92 * z9;
         A9[i+92] = a9;
         a10 += w92 * z10;
         A10[i+92] = a10;
         a11 += w92 * z11;
         A11[i+92] = a11;
         a0 = A0[i+93];
         a0 += x93 * y0;
         a1 = A1[i+93];
         a1 += x93 * y1;
         a2 = A2[i+93];
         a2 += x93 * y2;
         a3 = A3[i+93];
         a3 += x93 * y3;
         a4 = A4[i+93];
         a4 += x93 * y4;
         a5 = A5[i+93];
         a5 += x93 * y5;
         a6 = A6[i+93];
         a6 += x93 * y6;
         a7 = A7[i+93];
         a7 += x93 * y7;
         a8 = A8[i+93];
         a8 += x93 * y8;
         a9 = A9[i+93];
         a9 += x93 * y9;
         a10 = A10[i+93];
         a10 += x93 * y10;
         a11 = A11[i+93];
         a11 += x93 * y11;
         a0 += w93 * z0;
         A0[i+93] = a0;
         a1 += w93 * z1;
         A1[i+93] = a1;
         a2 += w93 * z2;
         A2[i+93] = a2;
         a3 += w93 * z3;
         A3[i+93] = a3;
         a4 += w93 * z4;
         A4[i+93] = a4;
         a5 += w93 * z5;
         A5[i+93] = a5;
         a6 += w93 * z6;
         A6[i+93] = a6;
         a7 += w93 * z7;
         A7[i+93] = a7;
         a8 += w93 * z8;
         A8[i+93] = a8;
         a9 += w93 * z9;
         A9[i+93] = a9;
         a10 += w93 * z10;
         A10[i+93] = a10;
         a11 += w93 * z11;
         A11[i+93] = a11;
         a0 = A0[i+94];
         a0 += x94 * y0;
         a1 = A1[i+94];
         a1 += x94 * y1;
         a2 = A2[i+94];
         a2 += x94 * y2;
         a3 = A3[i+94];
         a3 += x94 * y3;
         a4 = A4[i+94];
         a4 += x94 * y4;
         a5 = A5[i+94];
         a5 += x94 * y5;
         a6 = A6[i+94];
         a6 += x94 * y6;
         a7 = A7[i+94];
         a7 += x94 * y7;
         a8 = A8[i+94];
         a8 += x94 * y8;
         a9 = A9[i+94];
         a9 += x94 * y9;
         a10 = A10[i+94];
         a10 += x94 * y10;
         a11 = A11[i+94];
         a11 += x94 * y11;
         a0 += w94 * z0;
         A0[i+94] = a0;
         a1 += w94 * z1;
         A1[i+94] = a1;
         a2 += w94 * z2;
         A2[i+94] = a2;
         a3 += w94 * z3;
         A3[i+94] = a3;
         a4 += w94 * z4;
         A4[i+94] = a4;
         a5 += w94 * z5;
         A5[i+94] = a5;
         a6 += w94 * z6;
         A6[i+94] = a6;
         a7 += w94 * z7;
         A7[i+94] = a7;
         a8 += w94 * z8;
         A8[i+94] = a8;
         a9 += w94 * z9;
         A9[i+94] = a9;
         a10 += w94 * z10;
         A10[i+94] = a10;
         a11 += w94 * z11;
         A11[i+94] = a11;
         a0 = A0[i+95];
         a0 += x95 * y0;
         a1 = A1[i+95];
         a1 += x95 * y1;
         a2 = A2[i+95];
         a2 += x95 * y2;
         a3 = A3[i+95];
         a3 += x95 * y3;
         a4 = A4[i+95];
         a4 += x95 * y4;
         a5 = A5[i+95];
         a5 += x95 * y5;
         a6 = A6[i+95];
         a6 += x95 * y6;
         a7 = A7[i+95];
         a7 += x95 * y7;
         a8 = A8[i+95];
         a8 += x95 * y8;
         a9 = A9[i+95];
         a9 += x95 * y9;
         a10 = A10[i+95];
         a10 += x95 * y10;
         a11 = A11[i+95];
         a11 += x95 * y11;
         a0 += w95 * z0;
         A0[i+95] = a0;
         a1 += w95 * z1;
         A1[i+95] = a1;
         a2 += w95 * z2;
         A2[i+95] = a2;
         a3 += w95 * z3;
         A3[i+95] = a3;
         a4 += w95 * z4;
         A4[i+95] = a4;
         a5 += w95 * z5;
         A5[i+95] = a5;
         a6 += w95 * z6;
         A6[i+95] = a6;
         a7 += w95 * z7;
         A7[i+95] = a7;
         a8 += w95 * z8;
         A8[i+95] = a8;
         a9 += w95 * z9;
         A9[i+95] = a9;
         a10 += w95 * z10;
         A10[i+95] = a10;
         a11 += w95 * z11;
         A11[i+95] = a11;

      }
      for (i=M96; i < M; i++)
      {
         const register float x0 = X[i], w0 = W[i];
         register float a0=A0[i], a1=A1[i], a2=A2[i], a3=A3[i], a4=A4[i],
                        a5=A5[i], a6=A6[i], a7=A7[i], a8=A8[i], a9=A9[i],
                        a10=A10[i], a11=A11[i];

         a0 += x0 * y0;
         a1 += x0 * y1;
         a2 += x0 * y2;
         a3 += x0 * y3;
         a4 += x0 * y4;
         a5 += x0 * y5;
         a6 += x0 * y6;
         a7 += x0 * y7;
         a8 += x0 * y8;
         a9 += x0 * y9;
         a10 += x0 * y10;
         a11 += x0 * y11;
         a0 += w0 * z0;
         A0[i] = a0;
         a1 += w0 * z1;
         A1[i] = a1;
         a2 += w0 * z2;
         A2[i] = a2;
         a3 += w0 * z3;
         A3[i] = a3;
         a4 += w0 * z4;
         A4[i] = a4;
         a5 += w0 * z5;
         A5[i] = a5;
         a6 += w0 * z6;
         A6[i] = a6;
         a7 += w0 * z7;
         A7[i] = a7;
         a8 += w0 * z8;
         A8[i] = a8;
         a9 += w0 * z9;
         A9[i] = a9;
         a10 += w0 * z10;
         A10[i] = a10;
         a11 += w0 * z11;
         A11[i] = a11;
      }
      Z += 12;
   }
/*
 * Do remaining columns with NU=1 cleanup
 */
   for (j=N-N12; j; j--, A += lda, Y++)
   {
      float *A0=A;
      const register float y0=Y[0], z0=Z[0];
      ATL_INT i;
      prefY(Y+1+1-1);
      prefY(Z+1+1-1);
      for (i=0; i < M96; i += 96)
      {
         register float a0;
         const float x0=X[i+0], w0=W[i+0], x1=X[i+1], w1=W[i+1], x2=X[i+2],
                     w2=W[i+2], x3=X[i+3], w3=W[i+3], x4=X[i+4], w4=W[i+4],
                     x5=X[i+5], w5=W[i+5], x6=X[i+6], w6=W[i+6], x7=X[i+7],
                     w7=W[i+7], x8=X[i+8], w8=W[i+8], x9=X[i+9], w9=W[i+9],
                     x10=X[i+10], w10=W[i+10], x11=X[i+11], w11=W[i+11],
                     x12=X[i+12], w12=W[i+12], x13=X[i+13], w13=W[i+13],
                     x14=X[i+14], w14=W[i+14], x15=X[i+15], w15=W[i+15],
                     x16=X[i+16], w16=W[i+16], x17=X[i+17], w17=W[i+17],
                     x18=X[i+18], w18=W[i+18], x19=X[i+19], w19=W[i+19],
                     x20=X[i+20], w20=W[i+20], x21=X[i+21], w21=W[i+21],
                     x22=X[i+22], w22=W[i+22], x23=X[i+23], w23=W[i+23],
                     x24=X[i+24], w24=W[i+24], x25=X[i+25], w25=W[i+25],
                     x26=X[i+26], w26=W[i+26], x27=X[i+27], w27=W[i+27],
                     x28=X[i+28], w28=W[i+28], x29=X[i+29], w29=W[i+29],
                     x30=X[i+30], w30=W[i+30], x31=X[i+31], w31=W[i+31],
                     x32=X[i+32], w32=W[i+32], x33=X[i+33], w33=W[i+33],
                     x34=X[i+34], w34=W[i+34], x35=X[i+35], w35=W[i+35],
                     x36=X[i+36], w36=W[i+36], x37=X[i+37], w37=W[i+37],
                     x38=X[i+38], w38=W[i+38], x39=X[i+39], w39=W[i+39],
                     x40=X[i+40], w40=W[i+40], x41=X[i+41], w41=W[i+41],
                     x42=X[i+42], w42=W[i+42], x43=X[i+43], w43=W[i+43],
                     x44=X[i+44], w44=W[i+44], x45=X[i+45], w45=W[i+45],
                     x46=X[i+46], w46=W[i+46], x47=X[i+47], w47=W[i+47],
                     x48=X[i+48], w48=W[i+48], x49=X[i+49], w49=W[i+49],
                     x50=X[i+50], w50=W[i+50], x51=X[i+51], w51=W[i+51],
                     x52=X[i+52], w52=W[i+52], x53=X[i+53], w53=W[i+53],
                     x54=X[i+54], w54=W[i+54], x55=X[i+55], w55=W[i+55],
                     x56=X[i+56], w56=W[i+56], x57=X[i+57], w57=W[i+57],
                     x58=X[i+58], w58=W[i+58], x59=X[i+59], w59=W[i+59],
                     x60=X[i+60], w60=W[i+60], x61=X[i+61], w61=W[i+61],
                     x62=X[i+62], w62=W[i+62], x63=X[i+63], w63=W[i+63],
                     x64=X[i+64], w64=W[i+64], x65=X[i+65], w65=W[i+65],
                     x66=X[i+66], w66=W[i+66], x67=X[i+67], w67=W[i+67],
                     x68=X[i+68], w68=W[i+68], x69=X[i+69], w69=W[i+69],
                     x70=X[i+70], w70=W[i+70], x71=X[i+71], w71=W[i+71],
                     x72=X[i+72], w72=W[i+72], x73=X[i+73], w73=W[i+73],
                     x74=X[i+74], w74=W[i+74], x75=X[i+75], w75=W[i+75],
                     x76=X[i+76], w76=W[i+76], x77=X[i+77], w77=W[i+77],
                     x78=X[i+78], w78=W[i+78], x79=X[i+79], w79=W[i+79],
                     x80=X[i+80], w80=W[i+80], x81=X[i+81], w81=W[i+81],
                     x82=X[i+82], w82=W[i+82], x83=X[i+83], w83=W[i+83],
                     x84=X[i+84], w84=W[i+84], x85=X[i+85], w85=W[i+85],
                     x86=X[i+86], w86=W[i+86], x87=X[i+87], w87=W[i+87],
                     x88=X[i+88], w88=W[i+88], x89=X[i+89], w89=W[i+89],
                     x90=X[i+90], w90=W[i+90], x91=X[i+91], w91=W[i+91],
                     x92=X[i+92], w92=W[i+92], x93=X[i+93], w93=W[i+93],
                     x94=X[i+94], w94=W[i+94], x95=X[i+95], w95=W[i+95];

         prefX(X);
         a0 = A0[i+0];
         a0 += x0 * y0;
         prefX(W);
         a0 += w0 * z0;
         prefA(A0);
         A0[i+0] = a0;
         a0 = A0[i+1];
         a0 += x1 * y0;
         a0 += w1 * z0;
         A0[i+1] = a0;
         a0 = A0[i+2];
         a0 += x2 * y0;
         a0 += w2 * z0;
         A0[i+2] = a0;
         a0 = A0[i+3];
         a0 += x3 * y0;
         a0 += w3 * z0;
         A0[i+3] = a0;
         a0 = A0[i+4];
         a0 += x4 * y0;
         a0 += w4 * z0;
         A0[i+4] = a0;
         a0 = A0[i+5];
         a0 += x5 * y0;
         a0 += w5 * z0;
         A0[i+5] = a0;
         a0 = A0[i+6];
         a0 += x6 * y0;
         a0 += w6 * z0;
         A0[i+6] = a0;
         a0 = A0[i+7];
         a0 += x7 * y0;
         a0 += w7 * z0;
         A0[i+7] = a0;
         a0 = A0[i+8];
         a0 += x8 * y0;
         a0 += w8 * z0;
         A0[i+8] = a0;
         a0 = A0[i+9];
         a0 += x9 * y0;
         a0 += w9 * z0;
         A0[i+9] = a0;
         a0 = A0[i+10];
         a0 += x10 * y0;
         a0 += w10 * z0;
         A0[i+10] = a0;
         a0 = A0[i+11];
         a0 += x11 * y0;
         a0 += w11 * z0;
         A0[i+11] = a0;
         a0 = A0[i+12];
         a0 += x12 * y0;
         a0 += w12 * z0;
         A0[i+12] = a0;
         a0 = A0[i+13];
         a0 += x13 * y0;
         a0 += w13 * z0;
         A0[i+13] = a0;
         a0 = A0[i+14];
         a0 += x14 * y0;
         a0 += w14 * z0;
         A0[i+14] = a0;
         a0 = A0[i+15];
         a0 += x15 * y0;
         a0 += w15 * z0;
         A0[i+15] = a0;
         a0 = A0[i+16];
         a0 += x16 * y0;
         a0 += w16 * z0;
         prefA(A0);
         A0[i+16] = a0;
         a0 = A0[i+17];
         a0 += x17 * y0;
         a0 += w17 * z0;
         A0[i+17] = a0;
         a0 = A0[i+18];
         a0 += x18 * y0;
         a0 += w18 * z0;
         A0[i+18] = a0;
         a0 = A0[i+19];
         a0 += x19 * y0;
         a0 += w19 * z0;
         A0[i+19] = a0;
         a0 = A0[i+20];
         a0 += x20 * y0;
         a0 += w20 * z0;
         A0[i+20] = a0;
         a0 = A0[i+21];
         a0 += x21 * y0;
         a0 += w21 * z0;
         A0[i+21] = a0;
         a0 = A0[i+22];
         a0 += x22 * y0;
         a0 += w22 * z0;
         A0[i+22] = a0;
         a0 = A0[i+23];
         a0 += x23 * y0;
         a0 += w23 * z0;
         A0[i+23] = a0;
         a0 = A0[i+24];
         a0 += x24 * y0;
         a0 += w24 * z0;
         A0[i+24] = a0;
         a0 = A0[i+25];
         a0 += x25 * y0;
         a0 += w25 * z0;
         A0[i+25] = a0;
         a0 = A0[i+26];
         a0 += x26 * y0;
         a0 += w26 * z0;
         A0[i+26] = a0;
         a0 = A0[i+27];
         a0 += x27 * y0;
         a0 += w27 * z0;
         A0[i+27] = a0;
         a0 = A0[i+28];
         a0 += x28 * y0;
         a0 += w28 * z0;
         A0[i+28] = a0;
         a0 = A0[i+29];
         a0 += x29 * y0;
         a0 += w29 * z0;
         A0[i+29] = a0;
         a0 = A0[i+30];
         a0 += x30 * y0;
         a0 += w30 * z0;
         A0[i+30] = a0;
         a0 = A0[i+31];
         a0 += x31 * y0;
         a0 += w31 * z0;
         A0[i+31] = a0;
         a0 = A0[i+32];
         a0 += x32 * y0;
         a0 += w32 * z0;
         prefA(A0);
         A0[i+32] = a0;
         a0 = A0[i+33];
         a0 += x33 * y0;
         a0 += w33 * z0;
         A0[i+33] = a0;
         a0 = A0[i+34];
         a0 += x34 * y0;
         a0 += w34 * z0;
         A0[i+34] = a0;
         a0 = A0[i+35];
         a0 += x35 * y0;
         a0 += w35 * z0;
         A0[i+35] = a0;
         a0 = A0[i+36];
         a0 += x36 * y0;
         a0 += w36 * z0;
         A0[i+36] = a0;
         a0 = A0[i+37];
         a0 += x37 * y0;
         a0 += w37 * z0;
         A0[i+37] = a0;
         a0 = A0[i+38];
         a0 += x38 * y0;
         a0 += w38 * z0;
         A0[i+38] = a0;
         a0 = A0[i+39];
         a0 += x39 * y0;
         a0 += w39 * z0;
         A0[i+39] = a0;
         a0 = A0[i+40];
         a0 += x40 * y0;
         a0 += w40 * z0;
         A0[i+40] = a0;
         a0 = A0[i+41];
         a0 += x41 * y0;
         a0 += w41 * z0;
         A0[i+41] = a0;
         a0 = A0[i+42];
         a0 += x42 * y0;
         a0 += w42 * z0;
         A0[i+42] = a0;
         a0 = A0[i+43];
         a0 += x43 * y0;
         a0 += w43 * z0;
         A0[i+43] = a0;
         a0 = A0[i+44];
         a0 += x44 * y0;
         a0 += w44 * z0;
         A0[i+44] = a0;
         a0 = A0[i+45];
         a0 += x45 * y0;
         a0 += w45 * z0;
         A0[i+45] = a0;
         a0 = A0[i+46];
         a0 += x46 * y0;
         a0 += w46 * z0;
         A0[i+46] = a0;
         a0 = A0[i+47];
         a0 += x47 * y0;
         a0 += w47 * z0;
         A0[i+47] = a0;
         a0 = A0[i+48];
         a0 += x48 * y0;
         a0 += w48 * z0;
         prefA(A0);
         A0[i+48] = a0;
         a0 = A0[i+49];
         a0 += x49 * y0;
         a0 += w49 * z0;
         A0[i+49] = a0;
         a0 = A0[i+50];
         a0 += x50 * y0;
         a0 += w50 * z0;
         A0[i+50] = a0;
         a0 = A0[i+51];
         a0 += x51 * y0;
         a0 += w51 * z0;
         A0[i+51] = a0;
         a0 = A0[i+52];
         a0 += x52 * y0;
         a0 += w52 * z0;
         A0[i+52] = a0;
         a0 = A0[i+53];
         a0 += x53 * y0;
         a0 += w53 * z0;
         A0[i+53] = a0;
         a0 = A0[i+54];
         a0 += x54 * y0;
         a0 += w54 * z0;
         A0[i+54] = a0;
         a0 = A0[i+55];
         a0 += x55 * y0;
         a0 += w55 * z0;
         A0[i+55] = a0;
         a0 = A0[i+56];
         a0 += x56 * y0;
         a0 += w56 * z0;
         A0[i+56] = a0;
         a0 = A0[i+57];
         a0 += x57 * y0;
         a0 += w57 * z0;
         A0[i+57] = a0;
         a0 = A0[i+58];
         a0 += x58 * y0;
         a0 += w58 * z0;
         A0[i+58] = a0;
         a0 = A0[i+59];
         a0 += x59 * y0;
         a0 += w59 * z0;
         A0[i+59] = a0;
         a0 = A0[i+60];
         a0 += x60 * y0;
         a0 += w60 * z0;
         A0[i+60] = a0;
         a0 = A0[i+61];
         a0 += x61 * y0;
         a0 += w61 * z0;
         A0[i+61] = a0;
         a0 = A0[i+62];
         a0 += x62 * y0;
         a0 += w62 * z0;
         A0[i+62] = a0;
         a0 = A0[i+63];
         a0 += x63 * y0;
         a0 += w63 * z0;
         A0[i+63] = a0;
         a0 = A0[i+64];
         a0 += x64 * y0;
         a0 += w64 * z0;
         prefA(A0);
         A0[i+64] = a0;
         a0 = A0[i+65];
         a0 += x65 * y0;
         a0 += w65 * z0;
         A0[i+65] = a0;
         a0 = A0[i+66];
         a0 += x66 * y0;
         a0 += w66 * z0;
         A0[i+66] = a0;
         a0 = A0[i+67];
         a0 += x67 * y0;
         a0 += w67 * z0;
         A0[i+67] = a0;
         a0 = A0[i+68];
         a0 += x68 * y0;
         a0 += w68 * z0;
         A0[i+68] = a0;
         a0 = A0[i+69];
         a0 += x69 * y0;
         a0 += w69 * z0;
         A0[i+69] = a0;
         a0 = A0[i+70];
         a0 += x70 * y0;
         a0 += w70 * z0;
         A0[i+70] = a0;
         a0 = A0[i+71];
         a0 += x71 * y0;
         a0 += w71 * z0;
         A0[i+71] = a0;
         a0 = A0[i+72];
         a0 += x72 * y0;
         a0 += w72 * z0;
         A0[i+72] = a0;
         a0 = A0[i+73];
         a0 += x73 * y0;
         a0 += w73 * z0;
         A0[i+73] = a0;
         a0 = A0[i+74];
         a0 += x74 * y0;
         a0 += w74 * z0;
         A0[i+74] = a0;
         a0 = A0[i+75];
         a0 += x75 * y0;
         a0 += w75 * z0;
         A0[i+75] = a0;
         a0 = A0[i+76];
         a0 += x76 * y0;
         a0 += w76 * z0;
         A0[i+76] = a0;
         a0 = A0[i+77];
         a0 += x77 * y0;
         a0 += w77 * z0;
         A0[i+77] = a0;
         a0 = A0[i+78];
         a0 += x78 * y0;
         a0 += w78 * z0;
         A0[i+78] = a0;
         a0 = A0[i+79];
         a0 += x79 * y0;
         a0 += w79 * z0;
         A0[i+79] = a0;
         a0 = A0[i+80];
         a0 += x80 * y0;
         a0 += w80 * z0;
         prefA(A0);
         A0[i+80] = a0;
         a0 = A0[i+81];
         a0 += x81 * y0;
         a0 += w81 * z0;
         A0[i+81] = a0;
         a0 = A0[i+82];
         a0 += x82 * y0;
         a0 += w82 * z0;
         A0[i+82] = a0;
         a0 = A0[i+83];
         a0 += x83 * y0;
         a0 += w83 * z0;
         A0[i+83] = a0;
         a0 = A0[i+84];
         a0 += x84 * y0;
         a0 += w84 * z0;
         A0[i+84] = a0;
         a0 = A0[i+85];
         a0 += x85 * y0;
         a0 += w85 * z0;
         A0[i+85] = a0;
         a0 = A0[i+86];
         a0 += x86 * y0;
         a0 += w86 * z0;
         A0[i+86] = a0;
         a0 = A0[i+87];
         a0 += x87 * y0;
         a0 += w87 * z0;
         A0[i+87] = a0;
         a0 = A0[i+88];
         a0 += x88 * y0;
         a0 += w88 * z0;
         A0[i+88] = a0;
         a0 = A0[i+89];
         a0 += x89 * y0;
         a0 += w89 * z0;
         A0[i+89] = a0;
         a0 = A0[i+90];
         a0 += x90 * y0;
         a0 += w90 * z0;
         A0[i+90] = a0;
         a0 = A0[i+91];
         a0 += x91 * y0;
         a0 += w91 * z0;
         A0[i+91] = a0;
         a0 = A0[i+92];
         a0 += x92 * y0;
         a0 += w92 * z0;
         A0[i+92] = a0;
         a0 = A0[i+93];
         a0 += x93 * y0;
         a0 += w93 * z0;
         A0[i+93] = a0;
         a0 = A0[i+94];
         a0 += x94 * y0;
         a0 += w94 * z0;
         A0[i+94] = a0;
         a0 = A0[i+95];
         a0 += x95 * y0;
         a0 += w95 * z0;
         A0[i+95] = a0;

      }
      for (i=M96; i < M; i++)
      {
         const register float x0 = X[i], w0 = W[i];
         register float a0=A0[i];

         a0 += x0 * y0;
         a0 += w0 * z0;
         A0[i] = a0;
      }
      Z++;
   }
}
